/***************************
 * Check and Radio buttons *
 ***************************/
/***************
 * Base States *
 ***************/
.background {
  color: #212121;
  background-color: #d6d6d6; }

dnd {
  color: #212121; }

.normal-icons {
  -gtk-icon-size: 16px; }

.large-icons {
  -gtk-icon-size: 32px; }

image:disabled {
  -gtk-icon-filter: opacity(0.5); }

.view, iconview,
textview > text {
  color: black;
  background-color: #f7f7f7; }
  .view:disabled, iconview:disabled,
  textview > text:disabled {
    color: #7c7c7c;
    background-color: #e3e3e3; }
  .view:selected:focus, iconview:selected:focus, .view:selected, iconview:selected,
  textview > text:selected:focus,
  textview > text:selected {
    border-radius: 3px; }

textview:drop(active) {
  caret-color: #4e9a06; }

textview > border {
  background-color: #e7e7e7; }

iconview:drop(active) {
  box-shadow: none; }

iconview > dndtarget:drop(active) {
  border-style: solid;
  border-width: 1px;
  border-color: #749651; }

rubberband, .content-view > rubberband, columnview.view > rubberband,
treeview.view > rubberband, gridview > rubberband, flowbox > rubberband {
  border: 1px solid #9ab87c;
  background-color: rgba(154, 184, 124, 0.3); }

flowbox > flowboxchild {
  padding: 3px; }

gridview > child {
  padding: 3px; }

gridview box {
  border-spacing: 8px;
  margin: 12px; }

coverflow cover {
  color: black;
  background-color: #f7f7f7;
  border: 1px solid black; }

label > selection {
  background-color: #9ab87c;
  color: #ffffff; }

label:disabled {
  color: #7c7c7c; }
  button label:disabled {
    color: inherit; }

label.error {
  color: #e35d4f; }
  label.error:disabled {
    color: rgba(227, 93, 79, 0.5); }

.dim-label, .titlebar:not(headerbar) .subtitle,
headerbar .subtitle, spinbutton.vertical > text > text > placeholder, spinbutton:not(.vertical) > text > placeholder,
entry > text > placeholder, label.separator {
  opacity: 0.55;
  text-shadow: none; }

window.assistant .sidebar {
  background-color: #f7f7f7;
  border-top: 1px solid #8a8a8a; }

window.assistant.csd .sidebar {
  border-top-style: none; }

window.assistant .sidebar > label {
  padding: 6px 12px; }

window.assistant .sidebar > label.highlight {
  background-color: #9ab87c;
  color: #ffffff; }

window.aboutdialog image.large-icons {
  -gtk-icon-size: 128px; }

.osd .scale-popup, .app-notification, .osd popover.background > arrow,
.osd popover.background > contents, popover.background.touch-selection > arrow,
popover.background.touch-selection > contents, popover.background.magnifier > arrow,
popover.background.magnifier > contents,
.osd {
  color: #eeeeec;
  border: none;
  background-color: rgba(53, 53, 53, 0.9);
  background-clip: padding-box;
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black; }

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    transform: rotate(1turn); } }

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  spinner:checked {
    opacity: 1;
    animation: spin 1s linear infinite; }
    spinner:checked:disabled {
      opacity: 0.5; }

/**********************
 * General Typography *
 **********************/
.large-title {
  font-weight: 300;
  font-size: 24pt; }

.title-1 {
  font-weight: 800;
  font-size: 20pt; }

.title-2 {
  font-weight: 800;
  font-size: 15pt; }

.title-3 {
  font-weight: 700;
  font-size: 15pt; }

.title-4 {
  font-weight: 700;
  font-size: 13pt; }

.heading {
  font-weight: 700;
  font-size: 11pt; }

.body {
  font-weight: 400;
  font-size: 11pt; }

.caption-heading {
  font-weight: 700;
  font-size: 9pt; }

.caption {
  font-weight: 400;
  font-size: 9pt; }

/****************
 * Text Entries *
 ****************/
spinbutton.vertical > text, spinbutton:not(.vertical),
entry {
  min-height: 28px;
  padding-left: 4px;
  padding-right: 4px;
  border: 1px solid;
  border-radius: 3px;
  color: black;
  border-color: #8a8a8a;
  background-color: #f7f7f7;
  background-image: linear-gradient(to bottom, #e3e3e3, #f7f7f7);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.04), inset -1px 0 rgba(0, 0, 0, 0.04), inset 0 -1px rgba(0, 0, 0, 0.02), 0 1px rgba(255, 255, 255, 0.4); }
  spinbutton.vertical > text > image.left, spinbutton:not(.vertical) > image.left,
  entry > image.left {
    margin-right: 6px; }
  spinbutton.vertical > text > image.right, spinbutton:not(.vertical) > image.right,
  entry > image.right {
    margin-left: 6px; }
  spinbutton.vertical > text.flat, spinbutton.flat:not(.vertical),
  entry.flat:focus-within,
  entry.flat:backdrop,
  entry.flat:disabled,
  entry.flat {
    min-height: 0;
    padding: 2px;
    background-color: transparent;
    border-color: transparent;
    border-radius: 0; }
  spinbutton.vertical > text:disabled, spinbutton:disabled:not(.vertical),
  entry:disabled {
    color: #7c7c7c;
    border-color: #a3a3a3;
    background-color: #d6d6d6;
    background-image: none; }
  spinbutton.vertical > text.error, spinbutton.error:not(.vertical),
  entry.error {
    color: #e35d4f;
    border-color: #e35d4f; }
    spinbutton.vertical > text.error:focus-within, spinbutton.error:focus-within:not(.vertical),
    entry.error:focus-within {
      border-color: #9ab87c; }
    spinbutton.vertical > text.error > selection, spinbutton.error:not(.vertical) > selection,
    entry.error > selection {
      background-color: #e35d4f; }
  spinbutton.vertical > text.warning, spinbutton.warning:not(.vertical),
  entry.warning {
    color: #f27e3f;
    border-color: #f27e3f; }
    spinbutton.vertical > text.warning:focus-within, spinbutton.warning:focus-within:not(.vertical),
    entry.warning:focus-within {
      border-color: #9ab87c; }
    spinbutton.vertical > text.warning > selection, spinbutton.warning:not(.vertical) > selection,
    entry.warning > selection {
      background-color: #f27e3f; }
  spinbutton.vertical > text > image, spinbutton:not(.vertical) > image,
  entry > image {
    color: #4c4c4c; }
    spinbutton.vertical > text > image:hover, spinbutton:not(.vertical) > image:hover,
    entry > image:hover {
      color: #212121; }
    spinbutton.vertical > text > image:active, spinbutton:not(.vertical) > image:active,
    entry > image:active {
      color: #9ab87c; }
  spinbutton.vertical > text.password image.caps-lock-indicator, spinbutton.password:not(.vertical) image.caps-lock-indicator,
  entry.password image.caps-lock-indicator {
    color: #4c4c4c; }
  spinbutton.vertical > text:drop(active), spinbutton:drop(active):not(.vertical),
  entry:drop(active):focus-within,
  entry:drop(active) {
    border-color: #4e9a06;
    box-shadow: inset 0 0 0 1px #4e9a06; }
  .osd spinbutton.vertical > text, .osd spinbutton:not(.vertical), .osd entry {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: rgba(0, 0, 0, 0.5);
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton.vertical > text:focus-within, .osd spinbutton:focus-within:not(.vertical), .osd entry:focus-within {
      color: white;
      border-color: #9ab87c;
      background-color: rgba(0, 0, 0, 0.5);
      background-clip: padding-box;
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton.vertical > text:disabled, .osd spinbutton:disabled:not(.vertical), .osd entry:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: rgba(71, 71, 71, 0.5);
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }

spinbutton.vertical > text > progress, spinbutton:not(.vertical) > progress,
entry > progress {
  margin: 2px -6px; }

spinbutton.vertical > text progress > trough > progress, spinbutton:not(.vertical) progress > trough > progress,
entry progress > trough > progress {
  background-color: transparent;
  background-image: none;
  border-radius: 0;
  border-width: 0 0 2px;
  border-color: #9ab87c;
  border-style: solid;
  box-shadow: none; }

spinbutton.vertical.linked:not(.vertical) > text:drop(active) + text, spinbutton.vertical.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + text, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), spinbutton.vertical.linked:not(.vertical) > text:drop(active) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + menubutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + menubutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + dropdown > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + dropdown > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + colorbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + colorbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + fontbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + fontbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + filechooserbutton > button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + filechooserbutton > button, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, spinbutton.vertical.linked:not(.vertical) > text:drop(active) + entry, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + entry, .linked:not(.vertical) > entry:drop(active) + button, .linked:not(.vertical) > entry:drop(active) + menubutton > button, .linked:not(.vertical) > entry:drop(active) + dropdown > button, .linked:not(.vertical) > entry:drop(active) + colorbutton > button, .linked:not(.vertical) > entry:drop(active) + fontbutton > button, .linked:not(.vertical) > entry:drop(active) + filechooserbutton > button, .linked:not(.vertical) > entry:drop(active) + combobox > box > button.combo, spinbutton.vertical.linked:not(.vertical) > entry:drop(active) + text, .linked:not(.vertical) > entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > entry:drop(active) + entry {
  border-left-color: #4e9a06; }

spinbutton.vertical.linked > text:not(:disabled) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), spinbutton.vertical.linked > text:not(:disabled) + text:not(:disabled), spinbutton.vertical.linked > spinbutton:not(:disabled):not(.vertical) + text:not(:disabled), spinbutton.vertical.linked > text:not(:disabled) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled), spinbutton.vertical.linked > entry:not(:disabled) + text:not(:disabled), .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) {
  border-top-color: #d6d6d6; }

spinbutton.vertical.linked > text:disabled + text:disabled, spinbutton.vertical.linked > spinbutton:disabled:not(.vertical) + text:disabled, spinbutton.vertical.linked > text:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), spinbutton.vertical.linked > text:disabled + entry:disabled, .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, spinbutton.vertical.linked > entry:disabled + text:disabled, .linked.vertical > entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > entry:disabled + entry:disabled {
  border-top-color: #d6d6d6; }

spinbutton.vertical.linked > text + text:drop(active):not(:only-child), spinbutton.vertical.linked > spinbutton:not(.vertical) + text:drop(active):not(:only-child), spinbutton.vertical.linked > text + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical),
spinbutton.vertical.linked > text + entry:drop(active):not(:only-child),
.linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), spinbutton.vertical.linked > entry + text:drop(active):not(:only-child), .linked.vertical > entry + spinbutton:drop(active):not(:only-child):not(.vertical),
.linked.vertical > entry + entry:drop(active):not(:only-child) {
  border-top-color: #4e9a06; }

spinbutton.vertical.linked > text:drop(active):not(:only-child) + text, spinbutton.vertical.linked > spinbutton:drop(active):not(:only-child):not(.vertical) + text, spinbutton.vertical.linked > text:drop(active):not(:only-child) + spinbutton:not(.vertical), .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical),
spinbutton.vertical.linked > text:drop(active):not(:only-child) + entry,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + menubutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + menubutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + dropdown > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + dropdown > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + colorbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + colorbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + fontbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + fontbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + filechooserbutton > button,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + filechooserbutton > button,
spinbutton.vertical.linked > text:drop(active):not(:only-child) + combobox > box > button.combo,
.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, spinbutton.vertical.linked > entry:drop(active):not(:only-child) + text, .linked.vertical > entry:drop(active):not(:only-child) + spinbutton:not(.vertical),
.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + menubutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + dropdown > button,
.linked.vertical > entry:drop(active):not(:only-child) + colorbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + fontbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + filechooserbutton > button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {
  border-top-color: #4e9a06; }

spinbutton.vertical > text.error, spinbutton.error:not(.vertical),
entry.error {
  color: #e35d4f; }

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) {
  background-color: #f7f7f7; }

treeview entry.flat, treeview entry {
  border-radius: 0;
  background-image: none;
  background-color: #f7f7f7; }
  treeview entry.flat:focus-within, treeview entry:focus-within {
    border-color: #9ab87c; }

/*******************
 * Editable Labels *
 *******************/
editablelabel > stack > text {
  color: black;
  border-color: #8a8a8a;
  background-color: #f7f7f7;
  background-image: linear-gradient(to bottom, #e3e3e3, #f7f7f7);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.04), inset -1px 0 rgba(0, 0, 0, 0.04), inset 0 -1px rgba(0, 0, 0, 0.02), 0 1px rgba(255, 255, 255, 0.4); }

/***********
 * Buttons *
 ***********/
@keyframes needs_attention {
  from {
    background-image: radial-gradient(farthest-side, #9ab87c 0%, rgba(154, 184, 124, 0) 0%); }
  to {
    background-image: radial-gradient(farthest-side, #9ab87c 95%, rgba(154, 184, 124, 0)); } }

notebook > header > tabs > arrow,
button {
  min-height: 18px;
  min-width: 14px;
  padding: 4px 7px;
  border: 1px solid;
  border-radius: 3px;
  color: #212121;
  border-color: #b0b0b0;
  border-bottom-color: #8a8a8a;
  background-image: linear-gradient(to bottom, white, #d1d1d1);
  box-shadow: inset 0 1px white, inset 1px 0 rgba(255, 255, 255, 0.4), inset -1px 0 rgba(255, 255, 255, 0.4), inset 0 -1px rgba(255, 255, 255, 0.2), 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
  text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
  -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
  notebook > header > tabs > arrow:hover,
  button:hover {
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #dbdbdb);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-filter: brightness(1.2); }
  notebook > header > tabs > arrow.keyboard-activating, notebook > header > tabs > arrow:active, notebook > header > tabs > arrow:checked,
  button.keyboard-activating,
  button:active,
  button:checked {
    color: #212121;
    border-color: #8a8a8a;
    background-image: linear-gradient(to bottom, #9e9e9e, #b0b0b0 30%, #b0b0b0);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
    text-shadow: none;
    -gtk-icon-shadow: none; }
  notebook > header > tabs > arrow:disabled,
  button:disabled {
    color: #7c7c7c;
    border-color: #a3a3a3;
    background-image: linear-gradient(to bottom, #d6d6d6, #c9c9c9);
    text-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 1px 0 rgba(255, 255, 255, 0.02), inset -1px 0 rgba(255, 255, 255, 0.02);
    -gtk-icon-filter: opacity(0.5); }
    notebook > header > tabs > arrow:disabled:active, notebook > header > tabs > arrow:disabled:checked,
    button:disabled:active,
    button:disabled:checked {
      color: #7c7c7c;
      border-color: #a3a3a3;
      background-image: linear-gradient(to bottom, #9e9e9e, #bdbdbd);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06); }
  button.sidebar-button, notebook > header > tabs > arrow, .toolbar > button,
  .toolbar > :not(.linked) > button,
  .toolbar :not(.linked) > menubutton > button,
  .toolbar :not(.linked) > scalebutton > button,
  .toolbar :not(.linked) > dropdown > button,
  .toolbar :not(.linked) > colorbutton > button,
  .toolbar :not(.linked) > fontbutton > button,
  .toolbar :not(.linked) > appchooserbutton > button,
  .toolbar :not(.linked) > combobox > box > button, notebook > header > tabs > arrow.flat,
  button.flat {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
    button.sidebar-button:hover, notebook > header > tabs > arrow:hover, .toolbar > button:hover,
    .toolbar > :not(.linked) > button:hover,
    .toolbar :not(.linked) > menubutton > button:hover,
    .toolbar :not(.linked) > scalebutton > button:hover,
    .toolbar :not(.linked) > dropdown > button:hover,
    .toolbar :not(.linked) > colorbutton > button:hover,
    .toolbar :not(.linked) > fontbutton > button:hover,
    .toolbar :not(.linked) > appchooserbutton > button:hover,
    .toolbar :not(.linked) > combobox > box > button:hover,
    button.flat:hover {
      color: #212121;
      border-color: #b0b0b0;
      border-bottom-color: #8a8a8a;
      background-image: linear-gradient(to bottom, white, #dbdbdb);
      text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
    button.keyboard-activating.sidebar-button, notebook > header > tabs > arrow.keyboard-activating, .toolbar > button.keyboard-activating,
    .toolbar > :not(.linked) > button.keyboard-activating,
    .toolbar :not(.linked) > menubutton > button.keyboard-activating,
    .toolbar :not(.linked) > scalebutton > button.keyboard-activating,
    .toolbar :not(.linked) > dropdown > button.keyboard-activating,
    .toolbar :not(.linked) > colorbutton > button.keyboard-activating,
    .toolbar :not(.linked) > fontbutton > button.keyboard-activating,
    .toolbar :not(.linked) > appchooserbutton > button.keyboard-activating,
    .toolbar :not(.linked) > combobox > box > button.keyboard-activating, button.sidebar-button:active, notebook > header > tabs > arrow:active, .toolbar > button:active,
    .toolbar > :not(.linked) > button:active,
    .toolbar :not(.linked) > menubutton > button:active,
    .toolbar :not(.linked) > scalebutton > button:active,
    .toolbar :not(.linked) > dropdown > button:active,
    .toolbar :not(.linked) > colorbutton > button:active,
    .toolbar :not(.linked) > fontbutton > button:active,
    .toolbar :not(.linked) > appchooserbutton > button:active,
    .toolbar :not(.linked) > combobox > box > button:active, button.sidebar-button:checked, notebook > header > tabs > arrow:checked, .toolbar > button:checked,
    .toolbar > :not(.linked) > button:checked,
    .toolbar :not(.linked) > menubutton > button:checked,
    .toolbar :not(.linked) > scalebutton > button:checked,
    .toolbar :not(.linked) > dropdown > button:checked,
    .toolbar :not(.linked) > colorbutton > button:checked,
    .toolbar :not(.linked) > fontbutton > button:checked,
    .toolbar :not(.linked) > appchooserbutton > button:checked,
    .toolbar :not(.linked) > combobox > box > button:checked,
    button.flat.keyboard-activating,
    button.flat:active,
    button.flat:checked {
      color: #212121;
      border-color: #8a8a8a;
      background-image: linear-gradient(to bottom, #9e9e9e, #b0b0b0 30%, #b0b0b0);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
      text-shadow: none;
      -gtk-icon-shadow: none; }
    button.sidebar-button:disabled, notebook > header > tabs > arrow:disabled, .toolbar > button:disabled,
    .toolbar > :not(.linked) > button:disabled,
    .toolbar :not(.linked) > menubutton > button:disabled,
    .toolbar :not(.linked) > scalebutton > button:disabled,
    .toolbar :not(.linked) > dropdown > button:disabled,
    .toolbar :not(.linked) > colorbutton > button:disabled,
    .toolbar :not(.linked) > fontbutton > button:disabled,
    .toolbar :not(.linked) > appchooserbutton > button:disabled,
    .toolbar :not(.linked) > combobox > box > button:disabled,
    button.flat:disabled {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
  notebook > header > tabs > arrow.image-button,
  button.image-button {
    min-width: 18px;
    padding: 4px; }
  notebook > header > tabs > arrow.text-button,
  button.text-button {
    padding: 4px 16px; }
  notebook > header > tabs > arrow.text-button.image-button,
  button.text-button.image-button {
    padding: 4px 7px; }
  notebook > header > tabs > arrow.text-button.image-button,
  button.text-button.image-button {
    padding: 4px 7px; }
    notebook > header > tabs > arrow.text-button.image-button label,
    button.text-button.image-button label {
      padding-left: 8px;
      padding-right: 8px; }
  notebook > header > tabs > arrow.arrow-button,
  button.arrow-button {
    padding-left: 10px;
    padding-right: 10px; }
    notebook > header > tabs > arrow.arrow-button > box,
    button.arrow-button > box {
      border-spacing: 4px; }
  dropdown:drop(active) button.combo,
  combobox:drop(active) button.combo, notebook > header > tabs > arrow:drop(active),
  button:drop(active) {
    color: #4e9a06;
    border-color: #4e9a06;
    box-shadow: inset 0 0 0 1px #4e9a06; }

row:selected button {
  border-color: #749651; }

row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled) {
  color: #ffffff;
  border-color: transparent; }


button.osd {
  min-width: 26px;
  min-height: 32px;
  color: #eeeeec;
  border-radius: 5px;
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(53, 53, 53, 0.9));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black;
  border: none;
  box-shadow: none; }
  
  button.osd.image-button {
    min-width: 34px; }
  
  button.osd:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(83, 83, 83, 0.9));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black;
    border: none;
    box-shadow: none; }
  
  button.osd:active,
  button.osd:checked {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(0, 0, 0, 0.7));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    border: none;
    box-shadow: none; }
  
  button.osd:disabled {
    color: #919190;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(71, 71, 71, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    border: none; }

.app-notification button, popover.background.touch-selection button, popover.background.magnifier button, .osd button {
  color: #eeeeec;
  border-color: rgba(0, 0, 0, 0.7);
  background-color: transparent;
  background-image: image(rgba(53, 53, 53, 0.9));
  background-clip: padding-box;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
  text-shadow: 0 1px black;
  -gtk-icon-shadow: 0 1px black; }
  .app-notification button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .osd button:hover {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(83, 83, 83, 0.9));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
  .app-notification button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .osd button:active, .osd button:checked {
    color: white;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(0, 0, 0, 0.7));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
  .app-notification button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .osd button:disabled {
    color: #919190;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(71, 71, 71, 0.5));
    background-clip: padding-box;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none; }
  .app-notification button.flat, popover.background.touch-selection button.flat, popover.background.magnifier button.flat, .osd button.flat {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    box-shadow: none;
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .app-notification button.flat:hover, popover.background.touch-selection button.flat:hover, popover.background.magnifier button.flat:hover, .osd button.flat:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(83, 83, 83, 0.9));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .app-notification button.flat:disabled, popover.background.touch-selection button.flat:disabled, popover.background.magnifier button.flat:disabled, .osd button.flat:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(71, 71, 71, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none;
      background-image: none;
      border-color: transparent;
      box-shadow: none; }
    .app-notification button.flat:active, popover.background.touch-selection button.flat:active, popover.background.magnifier button.flat:active, .app-notification button.flat:checked, popover.background.touch-selection button.flat:checked, popover.background.magnifier button.flat:checked, .osd button.flat:active, .osd button.flat:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(0, 0, 0, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }


button.suggested-action {
  color: white;
  border-color: #288251;
  border-bottom-color: #226e44;
  background-image: linear-gradient(to bottom, #54ca8a, #35ac6b);
  box-shadow: inset 0 1px #70d39d, inset 1px 0 #51c987, inset -1px 0 #51c987, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
  text-shadow: none; }
  
  button.suggested-action.flat {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #3abc75; }
  
  button.suggested-action:hover {
    color: white;
    border-color: #226e44;
    border-bottom-color: #1c5b38;
    background-image: linear-gradient(to bottom, #41c47d, #2f995f);
    box-shadow: inset 0 1px #5ccd8f, inset 1px 0 #3dc37a, inset -1px 0 #3dc37a, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
    text-shadow: none; }
  
  button.suggested-action:active,
  button.suggested-action:checked {
    color: white;
    border-color: #288251;
    background-image: linear-gradient(to bottom, #206640, #288251 30%, #288251);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
    text-shadow: none;
    -gtk-icon-shadow: none; }
  
  button.suggested-action.flat:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(58, 188, 117, 0.8); }
  
  button.suggested-action:disabled {
    color: #7c7c7c;
    border-color: #a3a3a3;
    background-image: linear-gradient(to bottom, #d6d6d6, #c9c9c9);
    text-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 1px 0 rgba(255, 255, 255, 0.02), inset -1px 0 rgba(255, 255, 255, 0.02); }
    
    button.suggested-action:disabled:active,
    button.suggested-action:disabled:checked {
      color: #b2e1c8;
      border-color: #288251;
      background-image: linear-gradient(to bottom, #9e9e9e, #bdbdbd);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06); }
  .osd button.suggested-action {
    color: #eeeeec;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(58, 188, 117, 0.5));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd button.suggested-action:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(58, 188, 117, 0.7));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd button.suggested-action:active:backdrop, .osd button.suggested-action:active, .osd button.suggested-action:checked:backdrop, .osd button.suggested-action:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(#3abc75);
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd button.suggested-action:disabled:backdrop, .osd button.suggested-action:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(71, 71, 71, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }


button.destructive-action {
  color: white;
  border-color: #9c1319;
  border-bottom-color: #851015;
  background-image: linear-gradient(to bottom, #e83c44, #ce1921);
  box-shadow: inset 0 1px #eb5c63, inset 1px 0 #e73840, inset -1px 0 #e73840, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
  text-shadow: none; }
  
  button.destructive-action.flat {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #e01b24; }
  
  button.destructive-action:hover {
    color: white;
    border-color: #851015;
    border-bottom-color: #6e0d12;
    background-image: linear-gradient(to bottom, #e5262e, #b7161d);
    box-shadow: inset 0 1px #e9454d, inset 1px 0 #e4212a, inset -1px 0 #e4212a, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
    text-shadow: none; }
  
  button.destructive-action:active,
  button.destructive-action:checked {
    color: white;
    border-color: #9c1319;
    background-image: linear-gradient(to bottom, #7c0f14, #9c1319 30%, #9c1319);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
    text-shadow: none;
    -gtk-icon-shadow: none; }
  
  button.destructive-action.flat:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: rgba(224, 27, 36, 0.8); }
  
  button.destructive-action:disabled {
    color: #7c7c7c;
    border-color: #a3a3a3;
    background-image: linear-gradient(to bottom, #d6d6d6, #c9c9c9);
    text-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 1px 0 rgba(255, 255, 255, 0.02), inset -1px 0 rgba(255, 255, 255, 0.02); }
    
    button.destructive-action:disabled:active,
    button.destructive-action:disabled:checked {
      color: #efa5a9;
      border-color: #9c1319;
      background-image: linear-gradient(to bottom, #9e9e9e, #bdbdbd);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06); }
  .osd button.destructive-action {
    color: #eeeeec;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(224, 27, 36, 0.5));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd button.destructive-action:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(224, 27, 36, 0.7));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd button.destructive-action:active:backdrop, .osd button.destructive-action:active, .osd button.destructive-action:checked:backdrop, .osd button.destructive-action:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(#e01b24);
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd button.destructive-action:disabled:backdrop, .osd button.destructive-action:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(71, 71, 71, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }

.stack-switcher > button > label {
  padding: 0 6px;
  margin: 0 -6px; }

.stack-switcher > button > image {
  padding: 3px 6px;
  margin: -3px -6px; }


button.font separator {
  background-color: transparent;
  border: none; }


button.font > box {
  border-spacing: 6px; }


button.font > box > box > label {
  font-weight: bold; }

menubutton.circular button,
button.circular {
  min-width: 32px;
  min-height: 32px;
  padding: 0;
  border-radius: 9999px; }
  menubutton.circular button label,
  button.circular label {
    padding: 0; }

stacksidebar row.needs-attention > label, .stack-switcher > button.needs-attention > label,
.stack-switcher > button.needs-attention > image {
  animation: needs_attention 150ms ease-in;
  background-image: radial-gradient(farthest-side, #9ab87c 96%, rgba(154, 184, 124, 0));
  background-size: 6px 6px, 6px 6px;
  background-repeat: no-repeat;
  background-position: right 3px, right 4px; }
  stacksidebar row.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > label:backdrop,
  .stack-switcher > button.needs-attention > image:backdrop {
    background-size: 6px 6px, 0 0; }
  stacksidebar row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl),
  .stack-switcher > button.needs-attention > image:dir(rtl) {
    background-position: left 3px, left 4px; }

.linked:not(.vertical) > filechooserbutton > combobox:dir(rtl):not(:last-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(rtl):not(:last-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(rtl):not(:last-child) > box > button.combo, .linked:not(.vertical) > filechooserbutton > combobox:dir(ltr):not(:first-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(ltr):not(:first-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(ltr):not(:first-child) > box > button.combo, dropdown.linked button:nth-child(2):dir(ltr),
combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > menubutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > dropdown:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > colorbutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > fontbutton:dir(rtl):not(:last-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(rtl):not(:last-child) > button, .linked:not(.vertical) > menubutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > dropdown:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > colorbutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > fontbutton:dir(ltr):not(:first-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(ltr):not(:first-child) > button, spinbutton.vertical.linked:not(.vertical) > text:dir(rtl):not(:last-child), .linked:not(.vertical) > spinbutton:dir(rtl):not(:last-child):not(.vertical), .linked:not(.vertical) > entry:dir(rtl):not(:last-child), .linked:not(.vertical) > button:dir(rtl):not(:last-child), spinbutton.vertical.linked:not(.vertical) > text:dir(ltr):not(:first-child), .linked:not(.vertical) > spinbutton:dir(ltr):not(:first-child):not(.vertical), .linked:not(.vertical) > entry:dir(ltr):not(:first-child), .linked:not(.vertical) > button:dir(ltr):not(:first-child) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0; }

.linked:not(.vertical) > filechooserbutton > combobox:dir(rtl):not(:first-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(rtl):not(:first-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(rtl):not(:first-child) > box > button.combo, .linked:not(.vertical) > filechooserbutton > combobox:dir(ltr):not(:last-child) > box > button.combo,
.linked:not(.vertical) > appchooserbutton > combobox:dir(ltr):not(:last-child) > box > button.combo,
.linked:not(.vertical) > combobox:dir(ltr):not(:last-child) > box > button.combo, dropdown.linked button:nth-child(2):dir(rtl),
combobox.linked button:nth-child(2):dir(rtl), .linked:not(.vertical) > menubutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > dropdown:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > colorbutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > fontbutton:dir(rtl):not(:first-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(rtl):not(:first-child) > button, .linked:not(.vertical) > menubutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > dropdown:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > colorbutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > fontbutton:dir(ltr):not(:last-child) > button,
.linked:not(.vertical) > filechooserbutton:dir(ltr):not(:last-child) > button, spinbutton.vertical.linked:not(.vertical) > text:dir(rtl):not(:first-child), .linked:not(.vertical) > spinbutton:dir(rtl):not(:first-child):not(.vertical), .linked:not(.vertical) > entry:dir(rtl):not(:first-child), .linked:not(.vertical) > button:dir(rtl):not(:first-child), spinbutton.vertical.linked:not(.vertical) > text:dir(ltr):not(:last-child), .linked:not(.vertical) > spinbutton:dir(ltr):not(:last-child):not(.vertical), .linked:not(.vertical) > entry:dir(ltr):not(:last-child), .linked:not(.vertical) > button:dir(ltr):not(:last-child) {
  border-right-style: none;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }

.linked.vertical > filechooserbutton > combobox:not(:first-child) > box > button.combo,
.linked.vertical > appchooserbutton > combobox:not(:first-child) > box > button.combo,
.linked.vertical > combobox:not(:first-child) > box > button.combo, .linked.vertical > menubutton:not(:first-child) > button,
.linked.vertical > dropdown:not(:first-child) > button,
.linked.vertical > colorbutton:not(:first-child) > button,
.linked.vertical > fontbutton:not(:first-child) > button,
.linked.vertical > filechooserbutton:not(:first-child) > button, spinbutton.vertical.linked > text:not(:first-child), .linked.vertical > spinbutton:not(:first-child):not(.vertical), .linked.vertical > entry:not(:first-child), .linked.vertical > button:not(:first-child) {
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

.linked.vertical > filechooserbutton > combobox:not(:last-child) > box > button.combo,
.linked.vertical > appchooserbutton > combobox:not(:last-child) > box > button.combo,
.linked.vertical > combobox:not(:last-child) > box > button.combo, .linked.vertical > menubutton:not(:last-child) > button,
.linked.vertical > dropdown:not(:last-child) > button,
.linked.vertical > colorbutton:not(:last-child) > button,
.linked.vertical > fontbutton:not(:last-child) > button,
.linked.vertical > filechooserbutton:not(:last-child) > button, spinbutton.vertical.linked > text:not(:last-child), .linked.vertical > spinbutton:not(:last-child):not(.vertical), .linked.vertical > entry:not(:last-child), .linked.vertical > button:not(:last-child) {
  border-bottom-style: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

.scale-popup button:hover, button.link:hover, button.link:active, button.link:checked, popover.menu box.circular-button button.circular.image-button.model,
list > row button.image-button:not(.flat), modelbutton.flat {
  background-color: transparent;
  background-image: none;
  border-color: transparent;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  -gtk-icon-shadow: none; }

/* menu buttons */
modelbutton.flat {
  min-height: 24px;
  padding-left: 8px;
  padding-right: 8px;
  border-radius: 3px; }
  modelbutton.flat:hover {
    background-color: #9ab87c;
    color: #ffffff; }
  modelbutton.flat:disabled {
    color: #7c7c7c; }

modelbutton.flat arrow {
  background: none;
  min-width: 16px;
  min-height: 16px;
  opacity: 0.3; }
  modelbutton.flat arrow:hover {
    background: none; }
  modelbutton.flat arrow.left {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  modelbutton.flat arrow.right {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

/* oldstyle toolbar buttons */
.toolbar > button,
.toolbar > :not(.linked) > button,
.toolbar :not(.linked) > menubutton > button,
.toolbar :not(.linked) > scalebutton > button,
.toolbar :not(.linked) > dropdown > button,
.toolbar :not(.linked) > colorbutton > button,
.toolbar :not(.linked) > fontbutton > button,
.toolbar :not(.linked) > appchooserbutton > button,
.toolbar :not(.linked) > combobox > box > button {
  margin: 1px; }

button.color {
  padding: 4px; }
  button.color > colorswatch:only-child {
    box-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
    button.color > colorswatch:only-child, button.color > colorswatch:only-child > overlay {
      border-radius: 0; }
    .osd button.color > colorswatch:only-child {
      box-shadow: none; }
  .osd button.color:disabled colorswatch:only-child, .osd button.color:active colorswatch:only-child, .osd button.color:checked colorswatch:only-child, button.color:disabled colorswatch:only-child, button.color:active colorswatch:only-child, button.color:checked colorswatch:only-child {
    box-shadow: none; }

/* list buttons */
/* tone down as per new designs, see issue #1473, #1748 */
popover.menu box.circular-button button.circular.image-button.model,
list > row button.image-button:not(.flat) {
  border: 1px solid rgba(138, 138, 138, 0.5); }
  popover.menu box.circular-button button.circular.image-button.model:hover,
  list > row button.image-button:not(.flat):hover {
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #dbdbdb);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
  popover.menu box.circular-button button.circular.image-button.model:active, popover.menu box.circular-button button.circular.image-button.model:checked,
  list > row button.image-button:not(.flat):active,
  list > row button.image-button:not(.flat):checked {
    color: #212121;
    border-color: #8a8a8a;
    background-image: linear-gradient(to bottom, #9e9e9e, #b0b0b0 30%, #b0b0b0);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
    text-shadow: none;
    -gtk-icon-shadow: none; }

/*********
 * Links *
 *********/
button.link,
link {
  color: #2a76c6;
  text-decoration: underline; }
  button.link:visited,
  link:visited {
    color: #800080; }
    *:selected button.link:visited, *:selected link:visited {
      color: #cc99cc; }
  button.link:hover,
  link:hover {
    color: #4a90d9; }
    *:selected button.link:hover, *:selected link:hover {
      color: #edf4fb; }
  button.link:active,
  link:active {
    color: #2a76c6; }
    *:selected button.link:active, *:selected link:active {
      color: #d4e4f4; }
  button.link:disabled,
  link:disabled {
    color: rgba(120, 120, 120, 0.8); }
  button.link:selected, *:selected button.link,
  link:selected, *:selected link {
    color: #d4e4f4; }

button.link {
  text-shadow: none; }
  button.link:hover, button.link:active, button.link:checked {
    text-shadow: none; }
  button.link > label {
    text-decoration: underline; }

/*****************
 * GtkSpinButton *
 *****************/
spinbutton {
  font-feature-settings: "tnum"; }
  spinbutton:not(.vertical) {
    padding: 0;
    border-spacing: 0;
    /* :not here just to bump specificity above that of the list button styling */ }
    .osd spinbutton:not(.vertical) > text, spinbutton:not(.vertical) > text {
      min-width: 28px;
      margin: 0;
      background: none;
      background-color: transparent;
      border: none;
      border-radius: 0;
      box-shadow: none;
      padding: 6px; }
    spinbutton:not(.vertical) > button.image-button.up:not(.flat),
    spinbutton:not(.vertical) > button.image-button.down:not(.flat) {
      min-height: 16px;
      margin: 0;
      padding-bottom: 0;
      padding-top: 0;
      border-width: 0;
      border-color: rgba(138, 138, 138, 0.3);
      border-radius: 0;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), inset 2px 0 rgba(255, 255, 255, 0.5), inset 1px 0 rgba(0, 0, 0, 0.4), inset -1px 0 rgba(255, 255, 255, 0.5), inset 0 -1px rgba(0, 0, 0, 0.04); }
      spinbutton:not(.vertical) > button.image-button.up:not(.flat):disabled,
      spinbutton:not(.vertical) > button.image-button.down:not(.flat):disabled {
        background-color: transparent;
        box-shadow: inset 1px 0 rgba(0, 0, 0, 0.2), inset -1px 0 rgba(255, 255, 255, 0.2), inset 0 1px rgba(255, 255, 255, 0.3); }
      spinbutton:not(.vertical) > button.image-button.up:not(.flat):active,
      spinbutton:not(.vertical) > button.image-button.down:not(.flat):active {
        box-shadow: inset 0 2px rgba(0, 0, 0, 0.05), inset 1px 0 rgba(0, 0, 0, 0.3), inset 0 -1px rgba(0, 0, 0, 0.04); }
      spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(ltr):last-child,
      spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(ltr):last-child {
        border-radius: 0 3px 3px 0; }
      spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl):first-child,
      spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl):first-child {
        border-radius: 3px 0 0 3px; }
  .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat),
  .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat) {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    color: #eeeeec;
    border-style: none none none solid;
    border-color: rgba(0, 0, 0, 0.4);
    border-radius: 0;
    box-shadow: none;
    -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl),
    .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl) {
      border-style: none solid none none; }
    .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):hover,
    .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):hover {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: #eeeeec;
      border-color: rgba(0, 0, 0, 0.5);
      background-color: rgba(238, 238, 236, 0.1);
      -gtk-icon-shadow: 0 1px black;
      box-shadow: none; }
    .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):disabled,
    .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):disabled {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none;
      color: #919190;
      border-color: rgba(0, 0, 0, 0.5);
      -gtk-icon-shadow: none;
      box-shadow: none; }
    .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(ltr):last-child,
    .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(ltr):last-child {
      border-radius: 0 3px 3px 0; }
    .osd spinbutton:not(.vertical) > button.image-button.up:not(.flat):dir(rtl):first-child,
    .osd spinbutton:not(.vertical) > button.image-button.down:not(.flat):dir(rtl):first-child {
      border-radius: 3px 0 0 3px; }
  spinbutton.vertical:disabled {
    color: #7c7c7c; }
  spinbutton.vertical:drop(active) {
    border-color: transparent;
    box-shadow: none; }
  spinbutton.vertical > text {
    min-height: 32px;
    min-width: 32px;
    padding: 0;
    border-radius: 0; }
  spinbutton.vertical button {
    min-height: 32px;
    min-width: 32px;
    padding: 0; }
  spinbutton.vertical button.up {
    border-bottom-style: none;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0; }
  spinbutton.vertical button.down {
    border-top-style: none;
    border-top-left-radius: 0;
    border-top-right-radius: 0; }
  .osd spinbutton.vertical > button:first-child {
    color: #eeeeec;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(53, 53, 53, 0.9));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton.vertical > button:first-child:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(83, 83, 83, 0.9));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd spinbutton.vertical > button:first-child:active {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(0, 0, 0, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd spinbutton.vertical > button:first-child:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(71, 71, 71, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
  treeview spinbutton:not(.vertical) {
    min-height: 0;
    border-style: none;
    border-radius: 0; }
    treeview spinbutton:not(.vertical) > text {
      min-height: 0;
      padding: 1px 2px; }

/**************
 * ComboBoxes *
 **************/
dropdown > popover.menu.background > contents {
  padding: 0; }

dropdown > button > box {
  border-spacing: 6px; }
  dropdown > button > box > stack > row.activatable:hover {
    background: none;
    box-shadow: none; }

dropdown arrow,
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px; }

dropdown > popover.background.menu > contents,
combobox > popover.background.menu > contents {
  padding: 4px 0;
  border-radius: 0; }

dropdown > popover.menu > contents modelbutton,
combobox > popover.menu > contents modelbutton {
  min-height: 16px;
  padding: 5px 6px;
  border-radius: 0; }

dropdown:drop(active),
combobox:drop(active) {
  box-shadow: none; }

dropdown popover,
combobox popover {
  padding: 0; }
  dropdown popover listview,
  combobox popover listview {
    margin: 4px 0; }
    dropdown popover listview > row.activatable,
    combobox popover listview > row.activatable {
      padding: 5px 6px; }
      dropdown popover listview > row.activatable:selected, dropdown popover listview > row.activatable:selected:hover,
      combobox popover listview > row.activatable:selected,
      combobox popover listview > row.activatable:selected:hover {
        color: #ffffff;
        background-color: #9ab87c;
        box-shadow: none; }
  dropdown popover .dropdown-searchbar,
  combobox popover .dropdown-searchbar {
    padding: 6px;
    border-bottom: 1px solid #8a8a8a; }

/************
 * Toolbars *
 ************/
searchbar > revealer > box, .toolbar {
  padding: 6px;
  border-spacing: 1px;
  background-color: #d6d6d6; }

.toolbar {
  padding: 4px 3px 3px 4px; }
  .osd .toolbar {
    background-color: transparent; }
  .toolbar.osd {
    padding: 13px;
    border: none;
    border-radius: 5px;
    background-color: rgba(53, 53, 53, 0.9); }
    .toolbar.osd.left, .toolbar.osd.right, .toolbar.osd.top, .toolbar.osd.bottom {
      border-radius: 0; }
  .toolbar.horizontal > separator, .toolbar.vertical > separator {
    border-color: transparent;
    border-left-color: rgba(0, 0, 0, 0.2);
    border-right-color: rgba(255, 255, 255, 0.3); }

searchbar > revealer > box {
  border-width: 0 0 1px;
  padding: 3px; }

searchbar > revealer > box {
  border-style: solid;
  border-color: #8a8a8a;
  background-color: #bfbfbf; }

/**************
 * GtkInfoBar *
 **************/
infobar {
  border-style: none;
  padding: 8px;
  border-spacing: 12px; }
  infobar.info {
    background-color: #9ab87c; }
    infobar.info button {
      color: #212121;
      border-color: #749651;
      border-bottom-color: #678648;
      background-image: linear-gradient(to bottom, #aec696, #90b16f);
      box-shadow: inset 0 1px #c0d3ae, inset 1px 0 #acc593, inset -1px 0 #acc593, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
      text-shadow: none; }
      infobar.info button.flat:hover, infobar.info button:hover {
        color: #212121;
        border-color: #7ba057;
        border-bottom-color: #6f904e;
        background-image: linear-gradient(to bottom, #b6cca0, #97b679);
        box-shadow: inset 0 1px #c8d8b8, inset 1px 0 #b4ca9d, inset -1px 0 #b4ca9d, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
        text-shadow: none; }
      infobar.info button.flat:active, infobar.info button:active, infobar.info button:checked {
        color: #212121;
        border-color: #749651;
        background-image: linear-gradient(to bottom, #627f45, #749651 30%, #749651);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
      infobar.info button.flat {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none; }
  infobar.question {
    background-color: #55c1ec; }
    infobar.question button {
      color: #212121;
      border-color: #19a4dc;
      border-bottom-color: #1693c5;
      background-image: linear-gradient(to bottom, #7acef0, #43baea);
      box-shadow: inset 0 1px #9adaf4, inset 1px 0 #75cdf0, inset -1px 0 #75cdf0, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
      text-shadow: none; }
      infobar.question button.flat:hover, infobar.question button:hover {
        color: #212121;
        border-color: #1eade6;
        border-bottom-color: #189dd3;
        background-image: linear-gradient(to bottom, #87d3f2, #50bfeb);
        box-shadow: inset 0 1px #a8dff5, inset 1px 0 #83d2f1, inset -1px 0 #83d2f1, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
        text-shadow: none; }
      infobar.question button.flat:active, infobar.question button:active, infobar.question button:checked {
        color: #212121;
        border-color: #19a4dc;
        background-image: linear-gradient(to bottom, #158cbc, #19a4dc 30%, #19a4dc);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
      infobar.question button.flat {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none; }
  infobar.warning {
    background-color: #f27e3f;
    color: #ffffff; }
    infobar.warning button {
      color: #ffffff;
      border-color: #d6550e;
      border-bottom-color: #be4b0d;
      background-image: linear-gradient(to bottom, #f59865, #f1712c);
      box-shadow: inset 0 1px #f7ae87, inset 1px 0 #f49460, inset -1px 0 #f49460, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
      text-shadow: none; }
      infobar.warning button.flat:hover, infobar.warning button:hover {
        color: #ffffff;
        border-color: #e45a0f;
        border-bottom-color: #cc510e;
        background-image: linear-gradient(to bottom, #f6a174, #f27b3a);
        box-shadow: inset 0 1px #f8b895, inset 1px 0 #f59e6f, inset -1px 0 #f59e6f, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
        text-shadow: none; }
      infobar.warning button.flat:active, infobar.warning button:active, infobar.warning button:checked {
        color: #ffffff;
        border-color: #d6550e;
        background-image: linear-gradient(to bottom, #b5470c, #d6550e 30%, #d6550e);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
      infobar.warning button.flat {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none; }
  infobar.error {
    background-color: #e35d4f;
    color: #ffffff; }
    infobar.error button {
      color: #ffffff;
      border-color: #c62f20;
      border-bottom-color: #b02a1c;
      background-image: linear-gradient(to bottom, #e97d72, #e04d3d);
      box-shadow: inset 0 1px #ee9a91, inset 1px 0 #e8796e, inset -1px 0 #e8796e, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
      text-shadow: none; }
      infobar.error button.flat:hover, infobar.error button:hover {
        color: #ffffff;
        border-color: #d33222;
        border-bottom-color: #bd2d1e;
        background-image: linear-gradient(to bottom, #eb8a7f, #e2594b);
        box-shadow: inset 0 1px #f0a69e, inset 1px 0 #ea867b, inset -1px 0 #ea867b, 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
        text-shadow: none; }
      infobar.error button.flat:active, infobar.error button:active, infobar.error button:checked {
        color: #ffffff;
        border-color: #c62f20;
        background-image: linear-gradient(to bottom, #a7281b, #c62f20 30%, #c62f20);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
      infobar.error button.flat {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none; }
  infobar infobar .close,
  infobar searchbar .close {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
    -gtk-icon-shadow: none;
    min-width: 16px;
    min-height: 16px;
    padding: 4px;
    border-radius: 50%; }
    infobar infobar .close:hover,
    infobar searchbar .close:hover {
      color: #212121;
      border-color: #b0b0b0;
      border-bottom-color: #8a8a8a;
      background-image: linear-gradient(to bottom, white, #dbdbdb);
      text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }

/*****************
 * Title buttons *
 *****************/
windowcontrols:not(.empty).start:dir(ltr), windowcontrols:not(.empty).end:dir(rtl) {
  margin-right: 7px; }

windowcontrols:not(.empty).start:dir(rtl), windowcontrols:not(.empty).end:dir(ltr) {
  margin-left: 7px; }

windowcontrols button {
  background-color: transparent;
  background-image: none;
  background-position: center;
  background-repeat: no-repeat;
  border-width: 0;
  box-shadow: none;
  text-shadow: none; }
  windowcontrols button.close, windowcontrols button.close:hover, windowcontrols button.close:active, windowcontrols button.close:checked, windowcontrols button.maximize, windowcontrols button.maximize:hover, windowcontrols button.maximize:active, windowcontrols button.maximize:checked, windowcontrols button.minimize, windowcontrols button.minimize:hover, windowcontrols button.minimize:active, windowcontrols button.minimize:checked {
    padding: 8px 3px 8px 3px;
    margin: 0 2px;
    min-height: 0;
    min-width: 0;
    background-image: none;
    background-color: transparent;
    border: none;
    box-shadow: none;
    color: #8a8a8a;
    -gtk-icon-shadow: 0 1px white; }
    windowcontrols button.close:hover, windowcontrols button.close:hover:hover, windowcontrols button.close:active:hover, windowcontrols button.close:checked:hover, windowcontrols button.maximize:hover, windowcontrols button.maximize:hover:hover, windowcontrols button.maximize:active:hover, windowcontrols button.maximize:checked:hover, windowcontrols button.minimize:hover, windowcontrols button.minimize:hover:hover, windowcontrols button.minimize:active:hover, windowcontrols button.minimize:checked:hover {
      color: #707070; }
    windowcontrols button.close:backdrop, windowcontrols button.close:hover:backdrop, windowcontrols button.close:active:backdrop, windowcontrols button.close:checked:backdrop, windowcontrols button.maximize:backdrop, windowcontrols button.maximize:hover:backdrop, windowcontrols button.maximize:active:backdrop, windowcontrols button.maximize:checked:backdrop, windowcontrols button.minimize:backdrop, windowcontrols button.minimize:hover:backdrop, windowcontrols button.minimize:active:backdrop, windowcontrols button.minimize:checked:backdrop {
      color: #a3a3a3;
      -gtk-icon-shadow: none; }

/***************
 * Header bars *
 ***************/
.titlebar:not(headerbar),
headerbar {
  padding: 0 7px;
  min-height: 42px;
  border-width: 0 0 1px;
  border-style: solid;
  border-color: #8a8a8a;
  border-radius: 0;
  background: #d6d6d6 linear-gradient(to bottom, #eaeaea, #b7b7b7);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.8);
  /* hide the close button separator */ }
  .titlebar:backdrop:not(headerbar),
  headerbar:backdrop {
    border-color: #999999;
    background-color: #d6d6d6;
    background-image: none;
    color: #7c7c7c; }
  .titlebar:not(headerbar) .title,
  headerbar .title {
    padding-left: 12px;
    padding-right: 12px;
    font-weight: bold; }
  .titlebar:not(headerbar) .subtitle,
  headerbar .subtitle {
    font-size: smaller;
    padding-left: 12px;
    padding-right: 12px; }
  .titlebar:not(headerbar) button:not(.titlebutton):backdrop,
  headerbar button:not(.titlebutton):backdrop {
    color: #7c7c7c; }
  .tiled .titlebar:not(headerbar), .tiled-top .titlebar:not(headerbar), .tiled-right .titlebar:not(headerbar), .tiled-bottom .titlebar:not(headerbar), .tiled-left .titlebar:not(headerbar), .maximized .titlebar:not(headerbar), .fullscreen .titlebar:not(headerbar), .tiled headerbar, .tiled-top headerbar, .tiled-right headerbar, .tiled-bottom headerbar, .tiled-left headerbar, .maximized headerbar, .fullscreen headerbar {
    border-radius: 0; }
  .default-decoration.titlebar:not(headerbar),
  headerbar.default-decoration {
    min-height: 28px;
    padding: 0 6px;
    border-bottom-width: 0;
    background-image: linear-gradient(to bottom, #eaeaea, #d6d6d6); }
    .default-decoration.titlebar:backdrop:not(headerbar),
    headerbar.default-decoration:backdrop {
      background-image: none;
      background-color: #d6d6d6; }
    .default-decoration.titlebar:not(headerbar) windowcontrols button,
    .default-decoration.titlebar:not(headerbar) windowcontrols menubutton,
    headerbar.default-decoration windowcontrols button,
    headerbar.default-decoration windowcontrols menubutton {
      min-height: 0;
      min-width: 22px;
      margin: 0;
      padding: 0; }
    .default-decoration.titlebar:not(headerbar) windowcontrols menubutton button,
    headerbar.default-decoration windowcontrols menubutton button {
      min-height: 20px;
      min-width: 20px;
      margin: 0;
      padding: 4px; }
  .titlebar:not(headerbar) separator.titlebutton,
  headerbar separator.titlebutton {
    opacity: 0; }
  .solid-csd .titlebar:dir(rtl):not(headerbar), .solid-csd .titlebar:dir(ltr):not(headerbar), .solid-csd headerbar:backdrop:dir(rtl), .solid-csd headerbar:backdrop:dir(ltr), .solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) {
    margin-left: -1px;
    margin-right: -1px;
    margin-top: -1px;
    border-radius: 0;
    box-shadow: none; }

headerbar > windowhandle > box,
headerbar > windowhandle > box > box.start,
headerbar > windowhandle > box > box.end {
  border-spacing: 6px; }

headerbar entry,
headerbar spinbutton,
headerbar separator:not(.sidebar),
headerbar button {
  margin-top: 6px;
  margin-bottom: 6px; }

headerbar menubutton > button {
  margin-top: 0px;
  margin-bottom: 0px; }

headerbar switch {
  margin-top: 10px;
  margin-bottom: 10px; }

.background .titlebar:backdrop, .background .titlebar {
  border-top-left-radius: 6px;
  border-top-right-radius: 6px; }

window.csd > .titlebar:not(headerbar) {
  padding: 0;
  background-color: transparent;
  background-image: none;
  border-style: none;
  border-color: transparent; }

.titlebar:not(headerbar) separator {
  background-color: #8a8a8a; }

window.devel headerbar.titlebar {
  background: #d6d6d6 cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(154, 184, 124, 0.2)), linear-gradient(to top, #b5b5b5, #bdbdbd 3px, #cccccc); }
  window.devel headerbar.titlebar:backdrop {
    background: #d6d6d6 cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#d6d6d6);
    /* background-color would flash */ }

/************
 * Pathbars *
 ************/
.path-bar > button.text-button, .path-bar > button.image-button, .path-bar > button {
  padding-left: 4px;
  padding-right: 4px; }

.path-bar > button.text-button.image-button label {
  padding-left: 0;
  padding-right: 0; }

.path-bar > button.text-button.image-button label:last-child, .path-bar > button label:last-child {
  padding-right: 8px; }

.path-bar > button.text-button.image-button label:first-child, .path-bar > button label:first-child {
  padding-left: 8px; }

.path-bar > button image {
  padding-left: 4px;
  padding-right: 4px; }

.path-bar > button.slider-button {
  padding-left: 0;
  padding-right: 0; }

/**************
 * Tree Views *
 **************/
columnview.view,
treeview.view {
  border-left-color: #8c8c8c;
  border-top-color: #d6d6d6;
  padding: 1px; }
  columnview.view:selected:focus, columnview.view:selected,
  treeview.view:selected:focus,
  treeview.view:selected {
    border-style: solid;
    border-width: 1px 0 1px 0;
    border-radius: 0;
    border-color: #707070;
    background-color: transparent;
    background-image: linear-gradient(to bottom, #9ab87c, #749651);
    color: #ffffff; }
  columnview.view:disabled,
  treeview.view:disabled {
    color: #7c7c7c; }
    columnview.view:disabled:selected,
    treeview.view:disabled:selected {
      color: #c2d4b0; }
  columnview.view.separator,
  treeview.view.separator {
    min-height: 2px;
    color: #8a8a8a; }
  columnview.view:drop(active),
  treeview.view:drop(active) {
    box-shadow: none; }
  columnview.view > dndtarget:drop(active),
  treeview.view > dndtarget:drop(active) {
    border-style: solid none;
    border-width: 1px;
    border-color: #9ab87c; }
    columnview.view > dndtarget:drop(active).after,
    treeview.view > dndtarget:drop(active).after {
      border-top-style: none; }
    columnview.view > dndtarget:drop(active).before,
    treeview.view > dndtarget:drop(active).before {
      border-bottom-style: none; }
  columnview.view.expander,
  treeview.view.expander {
    min-width: 16px;
    min-height: 16px;
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: #4a4a4a; }
    columnview.view.expander:dir(rtl),
    treeview.view.expander:dir(rtl) {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
    columnview.view.expander:hover,
    treeview.view.expander:hover {
      color: black; }
    columnview.view.expander:selected,
    treeview.view.expander:selected {
      color: #e1ead8; }
      columnview.view.expander:selected:hover,
      treeview.view.expander:selected:hover {
        color: #ffffff; }
    columnview.view.expander:checked,
    treeview.view.expander:checked {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  columnview.view.progressbar, columnview.view.progressbar:selected,
  treeview.view.progressbar,
  treeview.view.progressbar:selected {
    color: #ffffff;
    border: none;
    border-radius: 2px;
    background-image: linear-gradient(to bottom, #c0d3ae, #8daf6b); }
  columnview.view.trough, columnview.view.trough:selected,
  treeview.view.trough,
  treeview.view.trough:selected {
    color: #212121;
    border: 1px solid #8a8a8a;
    border-radius: 3px;
    background-image: linear-gradient(to bottom, #c9c9c9, #fcfcfc); }
  columnview.view > header > button,
  treeview.view > header > button {
    color: #212121;
    text-shadow: none; }
    columnview.view > header > button sort-indicator,
    treeview.view > header > button sort-indicator {
      min-height: 16px;
      min-width: 16px; }
      columnview.view > header > button sort-indicator.ascending,
      treeview.view > header > button sort-indicator.ascending {
        -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
      columnview.view > header > button sort-indicator.descending,
      treeview.view > header > button sort-indicator.descending {
        -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  columnview.view button.dnd:active, columnview.view button.dnd:selected, columnview.view button.dnd:hover, columnview.view button.dnd,
  columnview.view header.button.dnd:active,
  columnview.view header.button.dnd:selected,
  columnview.view header.button.dnd:hover,
  columnview.view header.button.dnd,
  treeview.view button.dnd:active,
  treeview.view button.dnd:selected,
  treeview.view button.dnd:hover,
  treeview.view button.dnd,
  treeview.view header.button.dnd:active,
  treeview.view header.button.dnd:selected,
  treeview.view header.button.dnd:hover,
  treeview.view header.button.dnd {
    padding: 0 6px;
    color: #f7f7f7;
    background-image: none;
    background-color: #9ab87c;
    border-style: none;
    border-radius: 0;
    box-shadow: inset 0 0 0 1px #f7f7f7;
    text-shadow: none;
    transition: none; }
  columnview.view acceleditor > label,
  treeview.view acceleditor > label {
    background-color: #9ab87c; }

columnview.view > header > button,
treeview.view > header > button {
  padding: 4px 6px;
  background-image: linear-gradient(to bottom, #f7f7f7, #ededed 50%, #d6d6d6);
  border-style: none solid solid none;
  border-color: #8a8a8a;
  border-radius: 0;
  text-shadow: none; }
  columnview.view > header > button:disabled,
  treeview.view > header > button:disabled {
    border-color: #d6d6d6;
    background-image: none; }
  columnview.view > header > button:last-child,
  treeview.view > header > button:last-child {
    border-right-style: none; }

/***************
 * Popovers   *
 ***************/
popover.background {
  background-color: transparent;
  font: initial; }
  popover.background > arrow,
  popover.background > contents {
    background-color: #f7f7f7;
    background-clip: border-box;
    border: 1px solid #8a8a8a;
    box-shadow: 0 2px 6px 1px rgba(0, 0, 0, 0.07); }
  popover.background > contents {
    padding: 8px;
    border-radius: 3px; }
    popover.background > contents > list,
    popover.background > contents > .view,
    popover.background > contents > iconview,
    popover.background > contents > .toolbar {
      border-style: none;
      background-color: transparent; }
    popover.background > contents separator {
      border: 1px solid transparent;
      border-top-color: rgba(0, 0, 0, 0.08);
      border-bottom-color: rgba(255, 255, 255, 0.35);
      margin: 2px 0; }
    popover.background > contents list separator {
      margin: 2px 0; }
  .osd popover.background, popover.background.touch-selection, popover.background.magnifier {
    background-color: transparent; }
    .osd popover.background > arrow,
    .osd popover.background > contents, popover.background.touch-selection > arrow,
    popover.background.touch-selection > contents, popover.background.magnifier > arrow,
    popover.background.magnifier > contents {
      border: 1px solid rgba(255, 255, 255, 0.1);
      box-shadow: none; }

magnifier {
  background-color: #f7f7f7; }

/**********************
 * Popover Base Menus *
 **********************/
popover.menu {
  padding: 0; }
  popover.menu box.inline-buttons {
    padding: 0 12px; }
    popover.menu box.inline-buttons button.image-button.model {
      color: #212121;
      border-color: #b0b0b0;
      border-bottom-color: #8a8a8a;
      background-image: linear-gradient(to bottom, white, #d1d1d1);
      box-shadow: inset 0 1px white, inset 1px 0 rgba(255, 255, 255, 0.4), inset -1px 0 rgba(255, 255, 255, 0.4), inset 0 -1px rgba(255, 255, 255, 0.2), 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
      text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
      popover.menu box.inline-buttons button.image-button.model, popover.menu box.inline-buttons button.image-button.model:dir(ltr) {
        margin-left: 6px; }
      popover.menu box.inline-buttons button.image-button.model:dir(rtl) {
        margin-right: 6px; }
      popover.menu box.inline-buttons button.image-button.model:focus {
        color: #212121;
        border-color: #b0b0b0;
        border-bottom-color: #8a8a8a;
        background-image: linear-gradient(to bottom, white, #dbdbdb);
        text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
        -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
      popover.menu box.inline-buttons button.image-button.model:active {
        color: #212121;
        border-color: #8a8a8a;
        background-image: linear-gradient(to bottom, #9e9e9e, #b0b0b0 30%, #b0b0b0);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
  popover.menu box.circular-button {
    padding: 12px 12px 6px; }
    popover.menu box.circular-button button.circular.image-button.model {
      padding: 11px; }
      popover.menu box.circular-button button.circular.image-button.model:focus {
        color: #212121;
        border-color: #b0b0b0;
        border-bottom-color: #8a8a8a;
        background-image: linear-gradient(to bottom, white, #dbdbdb);
        text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
        -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
      popover.menu box.circular-button button.circular.image-button.model:active {
        color: #212121;
        border-color: #8a8a8a;
        background-image: linear-gradient(to bottom, #9e9e9e, #b0b0b0 30%, #b0b0b0);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.08), inset -1px 0 rgba(0, 0, 0, 0.08), inset 0 -1px rgba(0, 0, 0, 0.06);
        text-shadow: none;
        -gtk-icon-shadow: none; }
  popover.menu accelerator {
    color: alpha(currentColor,0.55); }
    popover.menu accelerator:dir(ltr) {
      margin-left: 12px; }
    popover.menu accelerator:dir(rtl) {
      margin-right: 12px; }
  popover.menu arrow.left,
  popover.menu radio.left,
  popover.menu check.left {
    margin-left: -1px;
    margin-right: 7px; }
  popover.menu arrow.right,
  popover.menu radio.right,
  popover.menu check.right {
    margin-left: 7px;
    margin-right: -1px; }
  popover.menu scale {
    padding: 5px 12px; }
  popover.menu modelbutton {
    min-height: 16px;
    min-width: 40px;
    padding: 5px 12px;
    border-radius: 2px; }
  popover.menu label.title {
    font-weight: bold;
    padding: 4px 32px; }

/*********
 * Menus *
 *********/
menubar {
  border: none;
  background-color: #d6d6d6; }
  menubar > item {
    padding: 4px 6px;
    border: 1px solid transparent; }
    menubar > item:selected {
      border-color: #8a8a8a;
      border-radius: 3px 3px 0 0;
      background-color: transparent;
      background-image: linear-gradient(to bottom, #9ab87c, #749651);
      color: #ffffff; }
    menubar > item:disabled {
      color: #7c7c7c;
      box-shadow: none; }
  menubar > item popover.menu modelbutton {
    border-radius: 0; }
  menubar > item popover.menu.background > contents {
    padding: 4px 0;
    border-radius: 2px; }
  menubar > item popover.menu popover.menu {
    margin-top: -5px; }

/*************
 * Notebooks *
 *************/
notebook {
  padding: 0; }
  notebook.frame {
    border: 1px solid #8a8a8a; }
    notebook.frame > header {
      margin: -1px; }
      notebook.frame > header.top {
        margin-bottom: 0;
        padding-left: 0;
        padding-right: 0; }
        notebook.frame > header.top > tabs {
          margin: 0;
          margin-right: -2px; }
  notebook > header {
    padding: 0;
    background-color: #d6d6d6; }
    notebook > header.top {
      padding-bottom: 0;
      box-shadow: inset 0 -1px #8a8a8a; }
      notebook > header.top > tabs > tab {
        padding: 2px 10px;
        min-width: 20px;
        min-height: 20px;
        margin-right: 2px;
        border: 1px solid #8a8a8a;
        border-radius: 4px 4px 0 0;
        background-color: transparent;
        background-image: linear-gradient(to bottom, #e3e3e3, #d1d1d1); }
        notebook > header.top > tabs > tab:checked {
          border-bottom: transparent;
          background-image: none;
          background-color: #f7f7f7; }
        notebook > header.top > tabs > tab:dir(rtl) {
          margin-right: 0;
          margin-left: 2px; }
    notebook > header.bottom {
      padding-top: 0;
      box-shadow: inset 0 1px #8a8a8a; }
      notebook > header.bottom > tabs > tab {
        padding: 2px 10px;
        min-width: 20px;
        min-height: 20px;
        margin-right: 2px;
        border: 1px solid #8a8a8a;
        border-radius: 0 0 4px 4px;
        background-color: transparent;
        background-image: linear-gradient(to top, #e3e3e3, #d1d1d1); }
        notebook > header.bottom > tabs > tab:checked {
          border-top: transparent;
          background-image: none;
          background-color: #f7f7f7; }
        notebook > header.bottom > tabs > tab:dir(rtl) {
          margin-right: 0;
          margin-left: 2px; }
    notebook > header.left {
      padding-right: 0;
      box-shadow: inset -1px 0 #8a8a8a; }
      notebook > header.left > tabs > tab {
        padding: 2px 10px;
        min-width: 20px;
        min-height: 20px;
        margin-bottom: 2px;
        border: 1px solid #8a8a8a;
        border-radius: 4px 0 0 4px;
        background-color: transparent;
        background-image: linear-gradient(to bottom, #e3e3e3, #d1d1d1); }
        notebook > header.left > tabs > tab:checked {
          border-right: transparent;
          background-image: none;
          background-color: #f7f7f7; }
    notebook > header.right {
      padding-left: 0;
      box-shadow: inset 1px 0 #8a8a8a; }
      notebook > header.right > tabs > tab {
        padding: 2px 10px;
        min-width: 20px;
        min-height: 20px;
        margin-bottom: 2px;
        border: 1px solid #8a8a8a;
        border-radius: 0 4px 4px 0;
        background-color: transparent;
        background-image: linear-gradient(to bottom, #e3e3e3, #d1d1d1); }
        notebook > header.right > tabs > tab:checked {
          border-left: transparent;
          background-image: none;
          background-color: #f7f7f7; }
    notebook > header.top > tabs > arrow {
      border-top-style: none; }
    notebook > header.bottom > tabs > arrow {
      border-bottom-style: none; }
    notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
      margin-left: -5px;
      margin-right: -5px;
      padding-left: 4px;
      padding-right: 4px; }
      notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
        -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
      notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
        -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
    notebook > header.left > tabs > arrow {
      border-left-style: none; }
    notebook > header.right > tabs > arrow {
      border-right-style: none; }
    notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
      margin-top: -5px;
      margin-bottom: -5px;
      padding-top: 4px;
      padding-bottom: 4px; }
      notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
        -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
      notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
        -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    notebook > header > tabs > arrow {
      min-height: 16px;
      min-width: 16px;
      border-radius: 0; }
      notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) {
        background-clip: padding-box;
        background-image: none;
        background-color: rgba(255, 255, 255, 0.3);
        border-color: transparent;
        box-shadow: none; }
      notebook > header > tabs > arrow:disabled {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none; }
    notebook > header tab button.flat {
      color: black;
      padding: 0;
      min-width: 20px;
      min-height: 20px; }
      notebook > header tab button.flat:last-child {
        margin-left: 4px;
        margin-right: -4px; }
      notebook > header tab button.flat:first-child {
        margin-left: -4px;
        margin-right: 4px; }
  notebook > stack:not(:only-child) {
    background-color: #f7f7f7; }
  paned.horizontal > notebook > header > tabs {
    margin-right: -2px; }
    paned.horizontal > notebook > header > tabs :dir(rtl) {
      margin-left: -2px;
      padding-right: 2px; }

/**************
 * Scrollbars *
 **************/
scrollbar {
  background-color: transparent;
  border-style: solid;
  border-color: rgba(138, 138, 138, 0.5); }
  scrollbar.vertical {
    border-width: 0 0 0 1px;
    background-image: linear-gradient(to right, #d6d6d6, #f7f7f7); }
  scrollbar.horizontal {
    border-width: 1px 0 0 0;
    background-image: linear-gradient(to bottom, #d6d6d6, #f7f7f7); }
  scrollbar.top {
    border-bottom: 1px solid rgba(138, 138, 138, 0.5); }
  scrollbar.bottom {
    border-top: 1px solid rgba(138, 138, 138, 0.5); }
  scrollbar.left {
    border-right: 1px solid rgba(138, 138, 138, 0.5); }
  scrollbar.right {
    border-left: 1px solid rgba(138, 138, 138, 0.5); }
  scrollbar slider {
    min-width: 10px;
    min-height: 10px;
    margin: -1px;
    margin-top: 2px;
    margin-bottom: 2px;
    border: 1px solid #8a8a8a;
    border-radius: 8px;
    background-clip: padding-box;
    background-color: transparent;
    background-image: linear-gradient(to right, whitesmoke, #c9c9c9); }
  scrollbar.horizontal slider {
    margin: -1px;
    margin-left: 2px;
    margin-right: 2px;
    background-image: linear-gradient(to bottom, whitesmoke, #c9c9c9); }
  scrollbar.fine-tune slider {
    min-width: 4px;
    min-height: 4px; }
  scrollbar.fine-tune.vertical slider {
    margin-left: 3px;
    margin-right: 3px; }
  scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
    border-color: transparent;
    opacity: 0.4;
    background-color: transparent;
    background-image: none; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
      margin: 0;
      min-width: 4px;
      min-height: 4px;
      background-color: #707070;
      background-image: none; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
      margin: 0 2px;
      min-width: 40px; }
    scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
      margin: 2px 0;
      min-height: 40px; }
  scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
    opacity: 0.8; }
  scrollbar.horizontal slider {
    min-width: 40px; }
  scrollbar.vertical slider {
    min-height: 40px; }

treeview ~ scrollbar.vertical {
  border-top: 1px solid #8a8a8a;
  margin-top: -1px; }

/**********
 * Switch *
 **********/
switch {
  border: 1px solid #8a8a8a;
  border-radius: 4px;
  color: #212121;
  background-color: #b0b0b0; }
  switch:checked {
    color: #ffffff;
    background-color: #9ab87c;
    text-shadow: 0 1px rgba(116, 150, 81, 0.5), 0 0 2px rgba(255, 255, 255, 0.6); }
  switch:disabled {
    color: #7c7c7c;
    border-color: #8a8a8a;
    background-color: #d6d6d6;
    text-shadow: none; }
  switch > slider {
    margin: -1px;
    min-width: 36px;
    min-height: 24px;
    border: 1px solid;
    border-radius: 4px;
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #d1d1d1);
    box-shadow: inset 0 1px white, inset 1px 0 rgba(255, 255, 255, 0.4), inset -1px 0 rgba(255, 255, 255, 0.4), inset 0 -1px rgba(255, 255, 255, 0.2), 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
  switch:hover > slider {
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #dbdbdb);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
  switch:disabled > slider {
    color: #7c7c7c;
    border-color: #a3a3a3;
    background-image: linear-gradient(to bottom, #d6d6d6, #c9c9c9);
    text-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 1px 0 rgba(255, 255, 255, 0.02), inset -1px 0 rgba(255, 255, 255, 0.02); }

/*************************
 * Check and Radio items *
 *************************/
.view.content-view.check:not(list), iconview.content-view.check:not(list),
.content-view .tile check:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: transparent;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: none;
  -gtk-icon-shadow: none; }

.view.content-view.check:hover:not(list), iconview.content-view.check:hover:not(list),
.content-view .tile check:hover:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: transparent;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: none;
  -gtk-icon-shadow: none; }

.view.content-view.check:active:not(list), iconview.content-view.check:active:not(list),
.content-view .tile check:active:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: transparent;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: none;
  -gtk-icon-shadow: none; }

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list),
.content-view .tile check:checked:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: #eeeeec;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: -gtk-icontheme('object-select-symbolic');
  -gtk-icon-shadow: none; }

.view.content-view.check:checked:hover:not(list), iconview.content-view.check:checked:hover:not(list),
.content-view .tile check:checked:hover:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: #eeeeec;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: -gtk-icontheme('object-select-symbolic');
  -gtk-icon-shadow: none; }

.view.content-view.check:checked:active:not(list), iconview.content-view.check:checked:active:not(list),
.content-view .tile check:checked:active:not(list) {
  margin: 4px;
  min-width: 32px;
  min-height: 32px;
  color: #eeeeec;
  background-color: #9ab87c;
  border-radius: 5px;
  background-image: none;
  box-shadow: none;
  border-width: 0;
  -gtk-icon-source: -gtk-icontheme('object-select-symbolic');
  -gtk-icon-shadow: none; }

checkbutton {
  border-spacing: 4px; }
  checkbutton.text-button {
    padding: 2px 0; }

check,
radio {
  min-height: 14px;
  min-width: 14px;
  border: 1px solid;
  -gtk-icon-source: none; }
  check,
  radio {
    background-clip: padding-box;
    background-image: linear-gradient(to bottom, #ebebeb 15%, white);
    border-color: #707070;
    box-shadow: 0 1px rgba(255, 255, 255, 0.5);
    color: #212121; }
  check:hover,
  radio:hover {
    background-image: linear-gradient(to bottom, #e0e0e0 15%, whitesmoke); }
  check:active,
  radio:active {
    box-shadow: inset 0 1px 1px 0px rgba(0, 0, 0, 0.2); }
  check:disabled,
  radio:disabled {
    box-shadow: none;
    background-image: linear-gradient(to bottom, #cfcfcf 15%, #e3e3e3);
    border-color: #a3a3a3;
    color: #7c7c7c; }
  check:checked,
  radio:checked {
    background-clip: border-box;
    background-image: linear-gradient(to bottom, #86aa62 15%, #9ab87c);
    border-color: #707070;
    box-shadow: 0 1px rgba(255, 255, 255, 0.5);
    color: #ffffff; }
  check:checked:hover,
  radio:checked:hover {
    background-image: linear-gradient(to bottom, #7ba057 15%, #90b16f); }
  check:checked:active,
  radio:checked:active {
    box-shadow: inset 0 1px 1px 0px rgba(0, 0, 0, 0.2); }
  check:checked:disabled,
  radio:checked:disabled {
    box-shadow: none;
    background-image: linear-gradient(to bottom, #cfcfcf 15%, #e3e3e3);
    border-color: #a3a3a3;
    color: #7c7c7c; }
  check:indeterminate,
  radio:indeterminate {
    background-clip: border-box;
    background-image: linear-gradient(to bottom, #86aa62 15%, #9ab87c);
    border-color: #707070;
    box-shadow: 0 1px rgba(255, 255, 255, 0.5);
    color: #ffffff; }
  check:indeterminate:hover,
  radio:indeterminate:hover {
    background-image: linear-gradient(to bottom, #7ba057 15%, #90b16f); }
  check:indeterminate:active,
  radio:indeterminate:active {
    box-shadow: inset 0 1px 1px 0px rgba(0, 0, 0, 0.2); }
  check:indeterminate:disabled,
  radio:indeterminate:disabled {
    box-shadow: none;
    background-image: linear-gradient(to bottom, #cfcfcf 15%, #e3e3e3);
    border-color: #a3a3a3;
    color: #7c7c7c; }
  .osd check, .osd radio {
    color: #eeeeec;
    border-color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
    background-image: image(rgba(53, 53, 53, 0.9));
    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    -gtk-icon-shadow: 0 1px black; }
    .osd check:hover, .osd radio:hover {
      color: #eeeeec;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(53, 53, 53, 0.9));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black; }
    .osd check:active, .osd radio:active {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(0, 0, 0, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
    .osd check:disabled, .osd radio:disabled {
      color: #919190;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(71, 71, 71, 0.5));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }


check {
  border-radius: 3px;
  -gtk-icon-size: 14px;
  -gtk-icon-shadow: 0 1px rgba(0, 0, 0, 0.6), 0 -1px rgba(0, 0, 0, 0.4), 1px 0 rgba(0, 0, 0, 0.4), -1px 0 rgba(0, 0, 0, 0.3); }
  
  check:checked {
    -gtk-icon-source: image(-gtk-recolor(url("assets/check-symbolic.svg")), -gtk-recolor(url("assets/check-symbolic.symbolic.png"))); }
  
  check:indeterminate {
    -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }
  
  check:disabled {
    -gtk-icon-shadow: none; }
  menu menuitem check:checked {
    -gtk-icon-source: image(-gtk-recolor(url("assets/menu-check-symbolic.svg")), -gtk-recolor(url("assets/menu-check-symbolic.symbolic.png"))); }
  menu menuitem check:indeterminate {
    -gtk-icon-source: image(-gtk-recolor(url("assets/menu-dash-symbolic.svg")), -gtk-recolor(url("assets/menu-dash-symbolic.symbolic.png"))); }

treeview.view radio:selected:focus, treeview.view radio:selected,
radio {
  border-radius: 100%;
  -gtk-icon-size: 14px;
  -gtk-icon-shadow: 0 1px rgba(0, 0, 0, 0.6), 0 -1px rgba(0, 0, 0, 0.4), 1px 0 rgba(0, 0, 0, 0.4), -1px 0 rgba(0, 0, 0, 0.3); }
  treeview.view radio:checked:selected,
  radio:checked {
    -gtk-icon-source: image(-gtk-recolor(url("assets/bullet-symbolic.svg")), -gtk-recolor(url("assets/bullet-symbolic.symbolic.png"))); }
  treeview.view radio:indeterminate:selected,
  radio:indeterminate {
    -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }
  treeview.view radio:disabled:selected,
  radio:disabled {
    -gtk-icon-shadow: none; }
  menu menuitem treeview.view radio:checked:selected, treeview.view menu menuitem radio:checked:selected, menu menuitem radio:checked {
    -gtk-icon-source: image(-gtk-recolor(url("assets/menu-bullet-symbolic.svg")), -gtk-recolor(url("assets/menu-bullet-symbolic.symbolic.png"))); }
  menu menuitem treeview.view radio:indeterminate:selected, treeview.view menu menuitem radio:indeterminate:selected, menu menuitem radio:indeterminate {
    -gtk-icon-source: image(-gtk-recolor(url("assets/menu-dash-symbolic.svg")), -gtk-recolor(url("assets/menu-dash-symbolic.symbolic.png"))); }

/************
 * GtkScale *
 ************/
progressbar.vertical > trough, progressbar > trough, scale fill, scale trough {
  border: 1px solid #8a8a8a;
  border-radius: 3px;
  background-color: #c9c9c9;
  box-shadow: inset 1px 1px rgba(0, 0, 0, 0.1), 0 1px rgba(255, 255, 255, 0.5); }
  progressbar > trough:disabled, scale fill:disabled, scale trough:disabled {
    border-color: #a3a3a3;
    background-color: #d1d1d1;
    background-image: none;
    box-shadow: none; }
  row:selected progressbar > trough, row:selected scale fill, scale row:selected fill, row:selected scale trough, scale row:selected trough {
    border-color: #749651; }
  .osd progressbar > trough, .osd scale fill, scale .osd fill, .osd scale trough, scale .osd trough {
    border-color: rgba(0, 0, 0, 0.7);
    background-color: rgba(0, 0, 0, 0.5);
    box-shadow: 0 1px rgba(255, 255, 255, 0.1); }
    .osd progressbar > trough:disabled, .osd scale fill:disabled, scale .osd fill:disabled, .osd scale trough:disabled, scale .osd trough:disabled {
      background-color: rgba(71, 71, 71, 0.5); }

progressbar > trough > progress, scale highlight, progressbar.vertical > trough > progress, scale.vertical highlight {
  border: 1px solid #749651;
  border-radius: 3px;
  background-image: linear-gradient(to bottom, #b4ca9d, #8bad68);
  box-shadow: 0 1px rgba(255, 255, 255, 0.05); }
  progressbar > trough > progress:disabled, scale highlight:disabled {
    border-color: #a3a3a3;
    background-color: #d1d1d1;
    background-image: none;
    box-shadow: none; }
  row:selected progressbar > trough > progress, row:selected scale highlight, scale row:selected highlight {
    border-color: #749651; }
  .osd progressbar > trough > progress, .osd scale highlight, scale .osd highlight {
    border-color: rgba(0, 0, 0, 0.7); }
    .osd progressbar > trough > progress:disabled, .osd scale highlight:disabled, scale .osd highlight:disabled {
      border-color: transparent; }

progressbar.vertical > trough > progress, scale.vertical highlight {
  background-image: linear-gradient(to right, #b4ca9d, #8bad68);
  box-shadow: 1px 0 rgba(255, 255, 255, 0.05); }
  progressbar.vertical > trough > progress:disabled, scale.vertical highlight:disabled {
    border-color: #a3a3a3;
    background-color: #d1d1d1;
    background-image: none;
    box-shadow: none; }

scale {
  min-height: 16px;
  min-width: 16px;
  padding: 3px; }
  scale fill,
  scale highlight {
    margin: -1px; }
  scale slider {
    min-height: 16px;
    min-width: 16px;
    margin: -7px; }
  scale.fine-tune slider {
    margin: -5px; }
  scale.fine-tune fill,
  scale.fine-tune highlight,
  scale.fine-tune trough {
    border-radius: 5px; }
  scale fill:disabled:backdrop, scale fill:disabled {
    border-color: transparent;
    background-color: transparent; }
  .osd scale fill {
    background-color: rgba(91, 91, 90, 0.775); }
    .osd scale fill:disabled:backdrop, .osd scale fill:disabled {
      border-color: transparent;
      background-color: transparent; }
  scale slider {
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #d1d1d1);
    box-shadow: inset 0 1px white, inset 1px 0 rgba(255, 255, 255, 0.4), inset -1px 0 rgba(255, 255, 255, 0.4), inset 0 -1px rgba(255, 255, 255, 0.2), 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    border: 1px solid #8a8a8a;
    border-radius: 100%; }
    scale slider:hover {
      color: #212121;
      border-color: #b0b0b0;
      border-bottom-color: #8a8a8a;
      background-image: linear-gradient(to bottom, white, #dbdbdb);
      text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
    scale slider:active {
      border-color: #749651; }
    scale slider:disabled {
      color: #7c7c7c;
      border-color: #a3a3a3;
      background-image: linear-gradient(to bottom, #d6d6d6, #c9c9c9);
      text-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.05), inset 1px 0 rgba(255, 255, 255, 0.02), inset -1px 0 rgba(255, 255, 255, 0.02); }
    row:selected scale slider:disabled, row:selected scale slider {
      border-color: #749651; }
    .osd scale slider {
      color: #eeeeec;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: transparent;
      background-image: image(rgba(53, 53, 53, 0.9));
      background-clip: padding-box;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      -gtk-icon-shadow: 0 1px black;
      border-color: rgba(0, 0, 0, 0.7);
      background-color: #353535; }
      .osd scale slider:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-color: transparent;
        background-image: image(rgba(83, 83, 83, 0.9));
        background-clip: padding-box;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        -gtk-icon-shadow: 0 1px black;
        background-color: #353535; }
      .osd scale slider:active {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-color: transparent;
        background-image: image(rgba(0, 0, 0, 0.7));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none;
        background-color: #353535; }
      .osd scale slider:disabled {
        color: #919190;
        border-color: rgba(0, 0, 0, 0.7);
        background-color: transparent;
        background-image: image(rgba(71, 71, 71, 0.5));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        -gtk-icon-shadow: none;
        background-color: #353535; }
  scale marks,
  scale value {
    color: alpha(currentColor,0.8);
    font-feature-settings: "tnum"; }
  scale value {
    margin-bottom: 5px; }
  scale.horizontal marks.top {
    margin-bottom: 4px;
    margin-top: -4px; }
  scale.horizontal marks.bottom {
    margin-top: 4px;
    margin-bottom: -4px; }
  scale.vertical marks.top {
    margin-right: 4px;
    margin-left: -4px; }
  scale.vertical marks.bottom {
    margin-left: 4px;
    margin-right: -4px; }
  scale.horizontal indicator {
    min-height: 5px;
    min-width: 1px; }
  scale.vertical indicator {
    min-height: 1px;
    min-width: 5px; }

/*****************
 * Progress bars *
 *****************/
progressbar {
  font-size: smaller;
  color: #212121;
  font-feature-settings: "tnum"; }
  progressbar.horizontal > trough {
    min-width: 150px; }
    progressbar.horizontal > trough, progressbar.horizontal > trough > progress {
      min-height: 5px; }
  progressbar.vertical > trough {
    min-height: 80px; }
    progressbar.vertical > trough, progressbar.vertical > trough > progress {
      min-width: 5px; }
  progressbar.horizontal > trough > progress {
    margin: 0 -1px; }
  progressbar.vertical > trough > progress {
    margin: -1px 0; }
  progressbar > trough {
    box-shadow: none;
    background-image: linear-gradient(to bottom, #c9c9c9, #fcfcfc); }
  progressbar.vertical > trough {
    box-shadow: none;
    background-image: linear-gradient(to right, #c9c9c9, #fcfcfc); }
  progressbar > trough > progress {
    border-radius: 1.5px; }
    progressbar > trough > progress.left {
      border-top-left-radius: 3px;
      border-bottom-left-radius: 3px; }
    progressbar > trough > progress.right {
      border-top-right-radius: 3px;
      border-bottom-right-radius: 3px; }
  progressbar.vertical > trough > progress {
    border-radius: 1.5px; }
    progressbar.vertical > trough > progress.top {
      border-top-right-radius: 2px;
      border-top-left-radius: 2px; }
    progressbar.vertical > trough > progress.bottom {
      border-bottom-right-radius: 2px;
      border-bottom-left-radius: 2px; }
  progressbar.osd {
    min-width: 3px;
    min-height: 3px;
    background-color: transparent; }
    progressbar.osd > trough {
      border-style: none;
      border-radius: 0;
      background-color: transparent;
      box-shadow: none; }
    progressbar.osd > progress {
      border-style: none;
      border-radius: 0; }
  progressbar > trough.empty > progress {
    all: unset; }

/*************
 * Level Bar *
 *************/
levelbar.horizontal trough > block {
  min-height: 3px; }

levelbar.horizontal.discrete trough > block {
  margin: 0 1px;
  min-width: 32px; }

levelbar.vertical trough > block {
  min-width: 3px; }

levelbar.vertical.discrete > trough > block {
  margin: 1px 0;
  min-height: 32px; }

levelbar > trough {
  border: 1px solid;
  padding: 2px;
  border-radius: 3px;
  color: black;
  border-color: #8a8a8a;
  background-color: #f7f7f7;
  background-image: linear-gradient(to bottom, #e3e3e3, #f7f7f7);
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), inset 1px 0 rgba(0, 0, 0, 0.04), inset -1px 0 rgba(0, 0, 0, 0.04), inset 0 -1px rgba(0, 0, 0, 0.02), 0 1px rgba(255, 255, 255, 0.4); }

levelbar > trough > block {
  border: 1px solid;
  border-radius: 2px; }
  levelbar > trough > block.low {
    border-color: #be4b0d;
    background-color: #f27e3f; }
  levelbar > trough > block.high, levelbar > trough > block:not(.empty) {
    border-color: #9ab87c;
    background-color: #9ab87c; }
  levelbar > trough > block.full {
    border-color: #3abc75;
    background-color: #3abc75; }
  levelbar > trough > block.empty {
    background-color: transparent;
    border-color: rgba(33, 33, 33, 0.2); }

/****************
 * Print dialog *
*****************/
window.dialog.print drawing {
  color: #212121;
  background: none;
  border: none;
  padding: 0; }
  window.dialog.print drawing paper {
    color: #212121;
    border: 1px solid #8a8a8a;
    background: white;
    padding: 0; }

window.dialog.print .dialog-action-box {
  margin: 12px; }

/**********
 * Frames *
 **********/
frame,
.frame {
  box-shadow: none;
  margin: 0;
  padding: 0;
  border-radius: 0;
  border: 1px solid #8a8a8a; }

frame > label {
  margin: 4px; }

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid #8a8a8a; }
  actionbar > revealer > box, actionbar > revealer > box > box.start, actionbar > revealer > box > box.end {
    border-spacing: 6px; }

scrolledwindow overshoot.top {
  background-image: radial-gradient(farthest-side at top, rgba(154, 184, 124, 0.2), rgba(154, 184, 124, 0));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: top;
  background-color: transparent;
  border: none;
  box-shadow: none; }

scrolledwindow overshoot.bottom {
  background-image: radial-gradient(farthest-side at bottom, rgba(154, 184, 124, 0.2), rgba(154, 184, 124, 0));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: bottom;
  background-color: transparent;
  border: none;
  box-shadow: none; }

scrolledwindow overshoot.left {
  background-image: radial-gradient(farthest-side at left, rgba(154, 184, 124, 0.2), rgba(154, 184, 124, 0));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: left;
  background-color: transparent;
  border: none;
  box-shadow: none; }

scrolledwindow overshoot.right {
  background-image: radial-gradient(farthest-side at right, rgba(154, 184, 124, 0.2), rgba(154, 184, 124, 0));
  background-size: 100% 60%;
  background-repeat: no-repeat;
  background-position: right;
  background-color: transparent;
  border: none;
  box-shadow: none; }

scrolledwindow > junction {
  border-color: transparent;
  border-image: linear-gradient(to bottom, #8a8a8a 1px, transparent 1px) 0 0 0 1/0 1px stretch;
  background-color: transparent; }
  scrolledwindow > junction:dir(rtl) {
    border-image-slice: 0 1 0 0; }

separator {
  min-height: 0;
  min-width: 0;
  border: 1px solid transparent;
  border-top-color: rgba(0, 0, 0, 0.08);
  border-bottom-color: rgba(255, 255, 255, 0.35); }
  separator.vertical {
    border-color: transparent;
    border-left-color: rgba(0, 0, 0, 0.08);
    border-right-color: rgba(255, 255, 255, 0.35); }

/*********
 * Lists *
 *********/
listview,
list {
  color: black;
  background-color: #f7f7f7;
  border-color: #8a8a8a; }
  listview > row,
  list > row {
    padding: 2px; }
  listview > row.expander,
  list > row.expander {
    padding: 0px; }
  listview > row.expander .row-header,
  list > row.expander .row-header {
    padding: 2px; }
  listview.horizontal row.separator, listview.separators.horizontal > row:not(.separator),
  list.horizontal row.separator,
  list.separators.horizontal > row:not(.separator) {
    border: 1px solid transparent;
    border-left-color: rgba(0, 0, 0, 0.08);
    border-right-color: rgba(255, 255, 255, 0.35); }
  listview:not(.horizontal) row.separator, listview.separators:not(.horizontal) > row:not(.separator),
  list:not(.horizontal) row.separator,
  list.separators:not(.horizontal) > row:not(.separator) {
    border: 1px solid transparent;
    border-top-color: rgba(0, 0, 0, 0.08);
    border-bottom-color: rgba(255, 255, 255, 0.35); }

row.activatable.has-open-popup, row.activatable:hover {
  background-color: #efefef; }

row.activatable:active {
  box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }

row.activatable:selected:active {
  box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }

row.activatable:selected.has-open-popup, row.activatable:selected:hover {
  background-color: #8ea973; }

columnview > listview > row {
  padding: 0; }
  columnview > listview > row > cell {
    padding: 8px 6px; }
    columnview > listview > row > cell:not(:first-child) {
      border-left: 1px solid transparent; }

columnview.column-separators > listview > row > cell {
  border-left-color: #8a8a8a; }

columnview.data-table > listview > row > cell {
  padding-top: 2px;
  padding-bottom: 2px; }

treeexpander {
  border-spacing: 4px; }

/********************************************************
 * Data Tables                                          *
 * treeview like tables with individual focusable cells *
 * https://gitlab.gnome.org/GNOME/gtk/-/issues/2929     *
 ********************************************************/
columnview row:not(:selected) cell editablelabel:not(.editing):focus-within {
  outline: 2px solid #8a8a8a; }

columnview row:not(:selected) cell editablelabel.editing:focus-within {
  outline: 2px solid #9ab87c; }

columnview row:not(:selected) cell editablelabel.editing text selection {
  background-color: #9ab87c;
  color: transparent; }

/*******************************************************
 * Rich Lists                                          *
 * Large list usually containing lots of widgets       *
 * https://gitlab.gnome.org/GNOME/gtk/-/issues/3073    *
 *******************************************************/
.rich-list {
  /* rich lists usually containing other widgets than just labels/text */ }
  .rich-list > row {
    padding: 8px 12px;
    min-height: 32px;
    /* should be tall even when only containing a label */ }
    .rich-list > row > box {
      border-spacing: 12px; }

/*********************
 * App Notifications *
 *********************/
.app-notification {
  padding: 10px;
  border-radius: 0 0 5px 5px;
  background-color: rgba(53, 53, 53, 0.9);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px);
  background-clip: padding-box; }
  .app-notification border {
    border: none; }

/*************
 * Expanders *
 *************/
expander title > arrow {
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  expander title > arrow:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
  expander title > arrow:hover {
    color: #6e6e6e; }
  expander title > arrow:disabled {
    color: #7c7c7c; }
  expander title > arrow:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

expander-widget > box > title {
  border-radius: 3px; }
  expander-widget > box > title:hover > expander {
    color: #6e6e6e; }

.navigation-sidebar:not(decoration):not(window):drop(active):focus, .navigation-sidebar:not(decoration):not(window):drop(active),
placessidebar:not(decoration):not(window):drop(active):focus,
placessidebar:not(decoration):not(window):drop(active),
stackswitcher:not(decoration):not(window):drop(active):focus,
stackswitcher:not(decoration):not(window):drop(active),
expander-widget:not(decoration):not(window):drop(active):focus,
expander-widget:not(decoration):not(window):drop(active) {
  box-shadow: none; }

/************
 * Calendar *
 ***********/
calendar {
  color: black;
  border: 1px solid #8a8a8a;
  padding: 2px;
  font-feature-settings: "tnum"; }
  calendar > header {
    border-bottom: 1px solid #8a8a8a; }
    calendar > header > button {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: none;
      text-shadow: none;
      -gtk-icon-shadow: none; }
  calendar > grid > label.today {
    box-shadow: inset 0px -2px #8a8a8a; }
    calendar > grid > label.today:selected {
      box-shadow: none; }
  calendar > grid > label:focus {
    outline-color: #9ab87c;
    outline-offset: -2px;
    outline-width: 2px;
    outline-style: solid; }
  calendar > grid > label.day-number {
    padding: 4px; }
    calendar > grid > label.day-number:selected {
      border-radius: 3px; }
  calendar > grid > label.day-number.other-month {
    color: alpha(currentColor,0.3); }

/***********
 * Dialogs *
 ***********/
window.dialog.message .titlebar {
  min-height: 20px;
  background-image: none;
  background-color: #d6d6d6;
  border-style: none;
  border-top-left-radius: 7px;
  border-top-right-radius: 7px; }

window.dialog.message box.dialog-vbox.vertical {
  border-spacing: 10px; }

window.dialog.message label.title {
  font-weight: 800;
  font-size: 15pt; }

window.dialog.message.csd.background {
  border-bottom-left-radius: 7px;
  border-bottom-right-radius: 7px; }

window.dialog.message.csd .dialog-action-area button {
  padding: 6px 16px;
  border-radius: 0;
  border-left-style: solid;
  border-right-style: none;
  border-bottom-style: none; }
  window.dialog.message.csd .dialog-action-area button:first-child {
    border-left-style: none;
    border-bottom-left-radius: 7px; }
  window.dialog.message.csd .dialog-action-area button:last-child {
    border-bottom-right-radius: 7px; }

filechooser .dialog-action-box {
  box-shadow: inset 0 1px #8a8a8a; }

filechooser #pathbarbox {
  border-bottom: 1px solid #8a8a8a;
  background-color: #d6d6d6; }

filechooserbutton > button > box {
  border-spacing: 6px; }

filechooserbutton:drop(active) {
  box-shadow: none;
  border-color: transparent; }

/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  background-color: #f7f7f7; }
  .sidebar:not(separator):dir(ltr), .sidebar:not(separator).left, .sidebar:not(separator).left:dir(rtl) {
    border-right: 1px solid #8a8a8a;
    border-left-style: none; }
  .sidebar:not(separator):dir(rtl), .sidebar:not(separator).right {
    border-left: 1px solid #8a8a8a;
    border-right-style: none; }
  .sidebar listview.view,
  .sidebar list {
    background-color: #f7f7f7; }
  paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
    border-style: none; }

stacksidebar row {
  padding: 10px 4px; }
  stacksidebar row > label {
    padding-left: 6px;
    padding-right: 6px; }
  stacksidebar row.needs-attention > label {
    background-size: 6px 6px, 0 0; }

separator.sidebar {
  background-color: #8a8a8a; }

/**********************
 * Navigation Sidebar *
 **********************/
.navigation-sidebar > separator {
  margin: 2px; }

.navigation-sidebar > row {
  min-height: 30px;
  padding: 0 8px;
  border-radius: 0;
  margin: 0 0 2px; }
  .navigation-sidebar > row:hover {
    background-color: #eaeaea; }
  .navigation-sidebar > row:selected {
    background-color: #9ab87c;
    color: #ffffff; }
    .navigation-sidebar > row:selected:hover {
      background-color: #8daf6b; }
  .navigation-sidebar > row:disabled {
    color: #7c7c7c; }

/****************
 * File chooser *
 ****************/
row image.sidebar-icon {
  opacity: 0.7; }

placessidebar .navigation-sidebar > row {
  min-height: 30px;
  padding: 0px; }
  placessidebar .navigation-sidebar > row > revealer {
    padding: 0 10px; }
  placessidebar .navigation-sidebar > row:selected {
    color: #ffffff; }
  placessidebar .navigation-sidebar > row:disabled {
    color: #7c7c7c; }
  placessidebar .navigation-sidebar > row image.sidebar-icon:dir(ltr) {
    padding-right: 8px; }
  placessidebar .navigation-sidebar > row image.sidebar-icon:dir(rtl) {
    padding-left: 8px; }
  placessidebar .navigation-sidebar > row label.sidebar-label:dir(ltr) {
    padding-right: 2px; }
  placessidebar .navigation-sidebar > row label.sidebar-label:dir(rtl) {
    padding-left: 2px; }
  button.sidebar-button {
    min-height: 22px;
    min-width: 22px;
    margin-top: 2px;
    margin-bottom: 2px;
    padding: 0;
    border-radius: 100%; }
  placessidebar .navigation-sidebar > row:selected:active {
    box-shadow: none; }
  placessidebar .navigation-sidebar > row.sidebar-placeholder-row {
    padding: 0 8px;
    min-height: 2px;
    background-image: image(#4e9a06);
    background-clip: content-box; }
  placessidebar .navigation-sidebar > row.sidebar-new-bookmark-row {
    color: #9ab87c; }
  placessidebar .navigation-sidebar > row:drop(active):not(:disabled) {
    color: #4e9a06;
    box-shadow: inset 0 1px #4e9a06, inset 0 -1px #4e9a06; }
    placessidebar .navigation-sidebar > row:drop(active):not(:disabled):selected {
      color: #ffffff;
      background-color: #4e9a06; }

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image {
  -gtk-icon-transform: rotate(-0.5turn); }

placesview row.activatable:hover {
  background-color: transparent; }

placesview > actionbar > revealer > box > box {
  border-spacing: 6px; }

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(#8a8a8a);
  background-size: 1px 1px; }
  paned > separator:selected {
    background-image: image(#9ab87c); }
  paned > separator.wide {
    min-width: 5px;
    min-height: 5px;
    background-color: transparent; }

paned.horizontal > separator {
  background-repeat: repeat-y;
  background-position: center;
  margin: 0 -3px 0 -3px;
  padding: 0 3px 0 3px; }
  paned.horizontal > separator.wide {
    background-repeat: no-repeat;
    background-size: 2px 24px;
    background-image: -gtk-scaled(url("assets/pane-separator-grip-vertical.png"), url("assets/pane-separator-grip-vertical@2.png")); }

paned.vertical > separator {
  margin: -3px 0 -3px 0;
  padding: 3px 0 3px 0;
  background-repeat: repeat-x;
  background-position: center; }
  paned.vertical > separator.wide {
    background-repeat: no-repeat;
    background-size: 24px 2px;
    background-image: -gtk-scaled(url("assets/pane-separator-grip.png"), url("assets/pane-separator-grip@2.png")); }

/**************
 * GtkVideo *
 **************/
video {
  background: black; }
  video image.osd {
    min-width: 64px;
    min-height: 64px;
    border-radius: 32px; }

/************
 * Tooltips *
 ************/
tooltip {
  padding: 4px;
  border-radius: 4px;
  box-shadow: none;
  text-shadow: none; }
  tooltip.background {
    background-color: #fbeaa0;
    background-clip: padding-box;
    border: 1px solid #8a8a8a; }
  tooltip > box {
    border-spacing: 6px; }

/*****************
 * Color Chooser *
 *****************/
colorswatch:drop(active), colorswatch {
  border-style: none; }

colorswatch.top {
  border-top-left-radius: 5.5px;
  border-top-right-radius: 5.5px; }
  colorswatch.top > overlay {
    border-top-left-radius: 5px;
    border-top-right-radius: 5px; }

colorswatch.bottom {
  border-bottom-left-radius: 5.5px;
  border-bottom-right-radius: 5.5px; }
  colorswatch.bottom > overlay {
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px; }

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 5.5px;
  border-bottom-left-radius: 5.5px; }
  colorswatch.left > overlay, colorswatch:first-child:not(.top) > overlay {
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px; }

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 5.5px;
  border-bottom-right-radius: 5.5px; }
  colorswatch.right > overlay, colorswatch:last-child:not(.bottom) > overlay {
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px; }

colorswatch.dark > overlay {
  color: white; }
  colorswatch.dark > overlay.activatable:hover > overlay {
    border-color: rgba(0, 0, 0, 0.8); }

colorswatch.light > overlay {
  color: black; }
  colorswatch.light > overlay.activatable:hover > overlay {
    border-color: rgba(0, 0, 0, 0.5); }

colorswatch:drop(active) {
  box-shadow: none; }
  colorswatch:drop(active).light > overlay {
    border-color: #4e9a06;
    box-shadow: inset 0 0 0 2px #3d7805, inset 0 0 0 1px #4e9a06; }
  colorswatch:drop(active).dark > overlay {
    border-color: #4e9a06;
    box-shadow: inset 0 0 0 2px rgba(0, 0, 0, 0.3), inset 0 0 0 1px #4e9a06; }

colorswatch > overlay {
  border: 1px solid rgba(0, 0, 0, 0.3); }
  colorswatch > overlay.activatable:hover > overaly {
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.4), inset 0 -1px rgba(0, 0, 0, 0.2); }

colorswatch#add-color-button {
  border-radius: 5px 5px 0 0; }
  colorswatch#add-color-button:only-child {
    border-radius: 5px; }
  colorswatch#add-color-button > overlay {
    color: #212121;
    border-color: #b0b0b0;
    border-bottom-color: #8a8a8a;
    background-image: linear-gradient(to bottom, white, #d1d1d1);
    box-shadow: inset 0 1px white, inset 1px 0 rgba(255, 255, 255, 0.4), inset -1px 0 rgba(255, 255, 255, 0.4), inset 0 -1px rgba(255, 255, 255, 0.2), 1px 0 rgba(0, 0, 0, 0.05), -1px 0 rgba(0, 0, 0, 0.05), 0 1px rgba(0, 0, 0, 0.1);
    text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
    -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }
    colorswatch#add-color-button > overlay.activatable:hover > overlay {
      color: #212121;
      border-color: #b0b0b0;
      border-bottom-color: #8a8a8a;
      background-image: linear-gradient(to bottom, white, #dbdbdb);
      text-shadow: 0 1px rgba(255, 255, 255, 0.769231);
      -gtk-icon-shadow: 0 1px rgba(255, 255, 255, 0.769231); }

colorswatch:disabled {
  opacity: 0.5; }
  colorswatch:disabled > overlay {
    border-color: rgba(0, 0, 0, 0.6);
    box-shadow: none; }

row:selected colorswatch {
  box-shadow: 0 0 0 2px #ffffff; }

colorswatch#editor-color-sample {
  border-radius: 4px; }
  colorswatch#editor-color-sample > overlay {
    border-radius: 4.5px; }

colorchooser .popover.osd {
  border-radius: 5px; }

/********
 * Misc *
 ********/
.content-view {
  background-color: #f7f7f7; }
  .content-view:hover {
    -gtk-icon-filter: brightness(1.2); }
  .content-view .tile {
    margin: 2px;
    background-color: transparent;
    border-radius: 0;
    padding: 0; }
    .content-view .tile:active, .content-view .tile:selected {
      background-color: transparent; }
    .content-view .tile:disabled {
      background-color: transparent; }

.osd .scale-popup button.flat {
  border-style: none;
  border-radius: 5px; }

.scale-popup button:hover {
  background-color: rgba(33, 33, 33, 0.1);
  border-radius: 5px; }

/**********************
 * Window Decorations *
 *********************/
window {
  border-width: 0px; }
  window.csd {
    box-shadow: 0 3px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(0, 0, 0, 0.23);
    margin: 0px;
    border-radius: 6px 6px 0 0; }
    window.csd:backdrop {
      box-shadow: 0 3px 9px 1px transparent, 0 2px 6px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.18); }
    window.csd.popup {
      box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }
    window.csd.dialog.message {
      border-radius: 6px;
      box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }
  .solid-csd window {
    margin: 0;
    padding: 4px;
    border: solid 1px #8a8a8a;
    border-radius: 0;
    box-shadow: inset 0 0 0 3px #d6d6d6, inset 0 1px rgba(255, 255, 255, 0.8); }
    .solid-csd window:backdrop {
      box-shadow: inset 0 0 0 3px #d6d6d6, inset 0 1px rgba(255, 255, 255, 0.8); }
  window.maximized, window.fullscreen {
    border-radius: 0;
    box-shadow: none; }
  window.tiled, window.tiled-top, window.tiled-right, window.tiled-bottom, window.tiled-left {
    border-radius: 0;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.23), 0 0 0 20px transparent; }
    window.tiled:backdrop, window.tiled-top:backdrop, window.tiled-right:backdrop, window.tiled-bottom:backdrop, window.tiled-left:backdrop {
      box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.18), 0 0 0 20px transparent; }
  .popup window {
    box-shadow: none; }
  .ssd window {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.23); }
  .ssd window:backdrop {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.18); }
  window tooltip.csd {
    border-radius: 5px;
    box-shadow: none; }

.view:selected:focus, .view:selected,
textview > text:selected:focus,
textview > text:selected, textview > text > selection:focus, textview > text > selection, iconview:selected:focus, iconview:selected, flowbox > flowboxchild:selected, gridview > child:selected,
entry > text > selection, editablelabel > stack > text > selection, modelbutton.flat:selected, spinbutton:not(.vertical) > text > selection, spinbutton.vertical > text > text > selection, row:selected, calendar > grid > label.day-number:selected {
  background-color: #9ab87c; }
  label:selected, .view:selected:focus, .view:selected,
  textview > text:selected:focus,
  textview > text:selected, textview > text > selection:focus, textview > text > selection, iconview:selected:focus, iconview:selected, flowbox > flowboxchild:selected, gridview > child:selected,
  entry > text > selection, editablelabel > stack > text > selection, modelbutton.flat:selected, spinbutton:not(.vertical) > text > selection, spinbutton.vertical > text > text > selection, row:selected, calendar > grid > label.day-number:selected {
    color: #ffffff; }
    label:disabled > selection, label:disabled:selected, .view:disabled:selected,
    textview > text:disabled:selected:focus,
    textview > text:disabled:selected, textview > text > selection:disabled, iconview:disabled:selected:focus, iconview:disabled:selected, flowbox > flowboxchild:disabled:selected, gridview > child:disabled:selected,
    entry > text > selection:disabled, editablelabel > stack > text > selection:disabled, modelbutton.flat:disabled:selected, spinbutton:not(.vertical) > text > selection:disabled, spinbutton.vertical > text > text > selection:disabled, row:disabled:selected, calendar > grid > label.day-number:disabled:selected {
      color: #cddcbe; }

.monospace {
  font-family: monospace; }

/**********************
 * Touch Copy & Paste *
 *********************/
cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none; }
  cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-start.png"), url("assets/text-select-start@2.png"));
    padding-left: 10px; }
  cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-end.png"), url("assets/text-select-end@2.png"));
    padding-right: 10px; }
  cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above.png"), url("assets/slider-horz-scale-has-marks-above@2.png")); }
  cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover.png"), url("assets/text-select-start-hover@2.png"));
    padding-left: 10px; }
  cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover.png"), url("assets/text-select-end-hover@2.png"));
    padding-right: 10px; }
  cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover.png"), url("assets/slider-horz-scale-has-marks-above-hover@2.png")); }
  cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active.png"), url("assets/text-select-start-active@2.png"));
    padding-left: 10px; }
  cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active.png"), url("assets/text-select-end-active@2.png"));
    padding-right: 10px; }
  cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) {
    -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active.png"), url("assets/slider-horz-scale-has-marks-above-active@2.png")); }

shortcuts-section {
  margin: 20px; }

.shortcuts-search-results {
  margin: 20px;
  border-spacing: 24px; }

shortcut {
  border-spacing: 6px; }

shortcut > .keycap {
  min-width: 16px;
  min-height: 20px;
  margin-top: 2px;
  padding-bottom: 3px;
  padding-left: 6px;
  padding-right: 6px;
  color: #212121;
  background-color: #f7f7f7;
  border: 1px solid;
  border-color: #b0b0b0;
  border-radius: 3px;
  box-shadow: inset 0 -3px #dddddd;
  font-size: smaller; }

:not(decoration):not(window):drop(active):focus,
:not(decoration):not(window):drop(active) {
  border-color: #4e9a06;
  box-shadow: inset 0 0 0 1px #4e9a06;
  caret-color: #4e9a06; }

stackswitcher.circular {
  border-spacing: 12px; }
  stackswitcher.circular > button.circular,
  stackswitcher.circular > button.text-button.circular {
    min-width: 32px;
    min-height: 32px;
    padding: 0; }

/*************
 * App Icons *
 *************/
/* Outline for low res icons */
.lowres-icon {
  -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/* Dropshadow for large icons */
.icon-dropshadow {
  -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/*********
 * Emoji *
 ********/
popover.emoji-picker > contents {
  padding-left: 0;
  padding-right: 0; }

.emoji-searchbar {
  padding: 6px;
  border-spacing: 6px;
  border-bottom: 1px solid #8a8a8a; }

button.emoji-section {
  border-color: transparent;
  border-width: 3px;
  border-style: none none solid;
  border-radius: 0;
  padding: 3px 0 0;
  min-width: 32px;
  min-height: 28px;
  /* reset props inherited from the button style */
  background: none;
  box-shadow: none;
  text-shadow: none; }
  button.emoji-section:hover {
    border-color: #8a8a8a; }
  button.emoji-section:checked {
    border-color: #9ab87c; }

popover.emoji-picker emoji {
  font-size: x-large;
  padding: 6px;
  border-radius: 6px; }
  popover.emoji-picker emoji:focus, popover.emoji-picker emoji:hover {
    background: #9ab87c; }

emoji-completion-row > box {
  border-spacing: 10px;
  padding: 2px 10px; }

emoji-completion-row:focus,
emoji-completion-row:hover {
  background-color: #9ab87c;
  color: #ffffff; }

emoji-completion-row emoji:focus,
emoji-completion-row emoji:hover {
  background-color: #9ab87c; }

popover.entry-completion > contents {
  padding: 0; }

statusbar {
  padding: 6px 10px 6px 10px; }

menubutton > button > box {
  border-spacing: 6px; }

menubutton arrow {
  min-height: 16px;
  min-width: 16px; }
  menubutton arrow.none {
    -gtk-icon-source: -gtk-icontheme("open-menu-symbolic"); }
  menubutton arrow.down {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
  menubutton arrow.up {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
  menubutton arrow.left {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
  menubutton arrow.right {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #212121;
/*
text color for entries, views and content in general */
@define-color theme_text_color black;
/*
widget base background color */
@define-color theme_bg_color #d6d6d6;
/*
text widgets and the like base background color */
@define-color theme_base_color #f7f7f7;
/*
base background color of selections */
@define-color theme_selected_bg_color #9ab87c;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #ffffff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #e3e3e3;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #7c7c7c;
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #f7f7f7;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #7c7c7c;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color black;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #d6d6d6;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #f4f4f4;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #9ab87c;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #ffffff;
/*
insensitive color on backdrop windows*/
@define-color unfocused_insensitive_color #b0b0b0;
/*
widgets main borders color */
@define-color borders #8a8a8a;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #999999;
/*
these are pretty self explicative */
@define-color warning_color #f27e3f;
@define-color error_color #e35d4f;
@define-color success_color #3abc75;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#212121, 1.8);
@define-color wm_unfocused_title #7c7c7c;
@define-color wm_highlight rgba(255, 255, 255, 0.8);
@define-color wm_borders_edge rgba(255, 255, 255, 0.8);
@define-color wm_bg_a shade(#d6d6d6, 1.08);
@define-color wm_bg_b #d6d6d6;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.23);
@define-color wm_button_color #8a8a8a;
@define-color wm_button_unfocused_color #a3a3a3;
@define-color wm_button_prelight_color #707070;
@define-color wm_button_hover_color_a shade(#d6d6d6, 1.3);
@define-color wm_button_hover_color_b #d6d6d6;
@define-color wm_button_active_color_a shade(#d6d6d6, 0.85);
@define-color wm_button_active_color_b shade(#d6d6d6, 0.89);
@define-color wm_button_active_color_c shade(#d6d6d6, 0.9);
/* content view background such as thumbnails view in Photos or Boxes */
@define-color content_view_bg #f7f7f7;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #f7f7f7;
